---- BLOCO ANONIMO (REORG TABLE PROC)
DECLARE

V_OWNER VARCHAR2(60 CHAR) := UPPER('&OWNER');
V_TABLE_NAME VARCHAR2(60 CHAR) := UPPER('&TABLE_NAME');

V_TB_SIZE VARCHAR2(30 CHAR) := NULL;


CURSOR C_REORG_1
IS
SELECT OWNER, TABLE_NAME, TABLESPACE_NAME, PARTITIONED
FROM DBA_TABLES
WHERE OWNER = V_OWNER
AND TABLE_NAME = V_TABLE_NAME;

CURSOR C_REORG_2
IS
SELECT TABLE_OWNER, TABLE_NAME, TABLESPACE_NAME, PARTITION_NAME
FROM DBA_TAB_PARTITIONS
WHERE TABLE_OWNER = V_OWNER
AND TABLE_NAME = V_TABLE_NAME;


CURSOR C_REORG_3
IS
SELECT TABLE_OWNER, TABLE_NAME, TABLESPACE_NAME, SUBPARTITION_NAME
FROM DBA_TAB_SUBPARTITIONS
WHERE TABLE_OWNER = V_OWNER
AND TABLE_NAME = V_TABLE_NAME;

CURSOR C_CHECK_TB_SIZE
IS
SELECT SUM(BYTES/1024/1024) AS MB FROM 
DBA_SEGMENTS 
WHERE OWNER = V_OWNER
AND SEGMENT_NAME = V_TABLE_NAME;


CURSOR C_REORG_IND1
IS
SELECT OWNER, INDEX_NAME, TABLE_OWNER, TABLE_NAME, TABLESPACE_NAME, PARTITIONED
FROM DBA_INDEXES 
WHERE TABLE_OWNER = V_OWNER
AND TABLE_NAME = V_TABLE_NAME;

CURSOR C_REORG_IND2
IS
SELECT P.INDEX_OWNER, P.INDEX_NAME, I.TABLE_OWNER, I.TABLE_NAME, P.TABLESPACE_NAME, P.PARTITION_NAME
FROM DBA_INDEXES I, DBA_IND_PARTITIONS P
WHERE I.TABLE_OWNER = V_OWNER
AND I.TABLE_NAME = V_TABLE_NAME
AND I.OWNER = P.INDEX_OWNER
AND I.INDEX_NAME = P.INDEX_NAME;

CURSOR C_REORG_IND3
IS
SELECT SUB.INDEX_OWNER, SUB.INDEX_NAME, I.TABLE_OWNER, I.TABLE_NAME, SUB.TABLESPACE_NAME, SUB.SUBPARTITION_NAME
FROM DBA_INDEXES I, DBA_IND_SUBPARTITIONS SUB
WHERE I.TABLE_OWNER = V_OWNER
AND I.TABLE_NAME = V_TABLE_NAME
AND I.OWNER = SUB.INDEX_OWNER
AND I.INDEX_NAME = SUB.INDEX_NAME;


BEGIN

FOR I IN C_CHECK_TB_SIZE LOOP

	V_TB_SIZE := I.MB;

	DBMS_OUTPUT.PUT_LINE('BEFORE REGORG TABLE SIZE: ' || V_TB_SIZE);

END LOOP;


FOR REC1 IN C_REORG_1 LOOP
	
	IF REC1.PARTITIONED = 'YES' THEN
	
		FOR REC3 IN C_REORG_3 LOOP
		
			IF REC3.SUBPARTITION_NAME IS NOT NULL THEN
			
				DBMS_OUTPUT.PUT_LINE('PERFORMED REORG ON SUBPARTITION: ' || REC3.SUBPARTITION_NAME);
			
				EXECUTE IMMEDIATE 'ALTER TABLE ' || V_OWNER || '.' || V_TABLE_NAME || ' MOVE SUBPARTITION ' || REC3.SUBPARTITION_NAME || ' TABLESPACE ' || REC3.TABLESPACE_NAME;
				
			END IF;

		END LOOP;
			
			
			FOR REC2 IN C_REORG_2 LOOP
			
				IF REC2.PARTITION_NAME IS NOT NULL THEN
			
					DBMS_OUTPUT.PUT_LINE('PERFORMED REORG ON PARTITION: ' || REC2.PARTITION_NAME);
					EXECUTE IMMEDIATE 'ALTER TABLE ' || V_OWNER || '.' || V_TABLE_NAME || ' MOVE PARTITION '  || REC2.PARTITION_NAME || ' TABLESPACE ' || REC2.TABLESPACE_NAME;
				
				ELSE 
				
					DBMS_OUTPUT.PUT_LINE('PERFORMED REORG ON TABLE: ' || V_TABLE_NAME);
						EXECUTE IMMEDIATE 'ALTER TABLE ' || V_OWNER || '.' || V_TABLE_NAME || ' MOVE TABLESPACE '  || REC1.TABLESPACE_NAME;
				
				END IF;
			END LOOP;
			
				FOR REC4 IN C_REORG_IND1 LOOP
					
					IF REC4.PARTITIONED = 'YES' THEN
					
						FOR REC5 IN C_REORG_IND3 LOOP
				
							IF REC5.SUBPARTITION_NAME IS NOT NULL THEN
				
								DBMS_OUTPUT.PUT_LINE('PERFORMED REORG ON INDEX SUBPARTITION: ' || REC5.SUBPARTITION_NAME);
								EXECUTE IMMEDIATE 'ALTER INDEX ' || REC5.INDEX_OWNER || '.' || REC5.INDEX_NAME || ' REBUILD SUBPARTITION ' || REC5.SUBPARTITION_NAME || ' TABLESPACE ' || REC5.TABLESPACE_NAME;
					
							END IF;
						END LOOP;
				
							FOR REC6 IN C_REORG_IND2 LOOP
					
								IF REC6.PARTITION_NAME IS NOT NULL THEN
						
									DBMS_OUTPUT.PUT_LINE('PERFORMED REORG ON INDEX PARTITION: ' || REC6.PARTITION_NAME);
									EXECUTE IMMEDIATE 'ALTER INDEX ' || REC6.INDEX_OWNER || '.' || REC6.INDEX_NAME || ' REBUILD PARTITION ' || REC6.PARTITION_NAME || ' TABLESPACE ' || REC6.TABLESPACE_NAME;
							
								ELSE 
						
									DBMS_OUTPUT.PUT_LINE('PERFORMED REORG ON INDEX: ' || REC4.INDEX_NAME);
									EXECUTE IMMEDIATE 'ALTER INDEX ' || REC4.OWNER || '.' || REC4.INDEX_NAME || ' REBUILD INDEX ONLINE';
								END IF;
							END LOOP;
					END IF;
				END LOOP;
				
	END IF;
END LOOP;

FOR I IN C_CHECK_TB_SIZE LOOP

	V_TB_SIZE := I.MB;

	DBMS_OUTPUT.PUT_LINE('AFTER REGORG TABLE SIZE: ' || V_TB_SIZE);

END LOOP;
END;
/