--- GET ALERT LOG FROM V$DIAG_INFO
COL ALERT_LOG FOR A90
SELECT D.VALUE || '/alert_' || I.INSTANCE_NAME || '.log' AS ALERT_LOG
FROM V$DIAG_INFO D, V$INSTANCE I
WHERE D.NAME = 'Diag Trace'
/


--- VERIFICAR STATUS CONTAINERS - 12C
SET LINES 200 PAGES 2000
COL OPEN_TIME FOR A32
COL NAME FOR A20
COL RECOVERY_STATUS FOR A15
COL RESTRICTED FOR A10
SELECT INST_ID, CON_ID, CON_UID, DBID, GUID, NAME, OPEN_MODE, RESTRICTED, OPEN_TIME, RECOVERY_STATUS
FROM GV$CONTAINERS
ORDER BY 1,2
/


--- VERIFICAR STATUS PDBS - 12C
SET LINES 200 PAGES 2000
COL OPEN_TIME FOR A32
COL NAME FOR A20
COL RECOVERY_STATUS FOR A15
COL RESTRICTED FOR A10
SELECT INST_ID, CON_ID, CON_UID, DBID, GUID, NAME, OPEN_MODE, RESTRICTED, OPEN_TIME, RECOVERY_STATUS
FROM GV$PDBS
ORDER BY 1,2
/


--- CHECK BACKUP STATUS RMAN
SET LINES 200 PAGES 2000
COL STATUS FOR A10
COL INPUT_MB FOR A10
COL OUTPUT_MB FOR A10
COL ELAPSED_TIME FOR A15
COL SESSION_RECID FOR A13
COL BKP_LEVEL FOR A10
ALTER SESSION SET NLS_DATE_FORMAT='DD/MM/YYYY HH24:MI:SS';
SELECT TO_CHAR(J.SESSION_RECID) AS SESSION_RECID
, S.SESSION_KEY
, J.SESSION_STAMP
, S.BS_KEY
, J.INPUT_TYPE
, TO_CHAR(ROUND(J.INPUT_BYTES/1024/1024)) AS INPUT_MB
, TO_CHAR(ROUND(J.OUTPUT_BYTES/1024/1024)) AS OUTPUT_MB
, J.START_TIME
, J.END_TIME
, J.TIME_TAKEN_DISPLAY AS ELAPSED_TIME
, J.STATUS
, TO_CHAR(S.INCREMENTAL_LEVEL) AS BKP_LEVEL
, CASE S.BACKUP_TYPE 
WHEN 'D' THEN 'CONTROLFILE'
WHEN 'L' THEN 'ARCHIVELOG'
WHEN 'I' THEN 'INCREMENTAL' 
END AS BACKUP_TYPE
FROM V$RMAN_BACKUP_JOB_DETAILS J
, V$BACKUP_SET_DETAILS S
WHERE J.SESSION_RECID = S.SESSION_RECID
AND J.SESSION_STAMP = S.SESSION_STAMP
ORDER BY J.START_TIME
/


--- ESCREVER NO ALERT.LOG MENSAGEM CUSTOMIZADA
EXEC DBMS_SYSTEM.KSDWRT(2, 'ORA-XXXXX: LEONARDO ALERT LOG MESSAGES');

--- LISTAR TABELAS DO MESMO OWNER EM TODOS OS PDBS - 12C (NAO LISTA TABELAS NOS CDBS "CDB$ROOT & PDB$SEED")
COLUMN PDB_NAME FORMAT A15
COLUMN OWNER FORMAT A15
COLUMN TABLE_NAME FORMAT A30
SELECT p.PDB_ID, p.PDB_NAME, t.OWNER, t.TABLE_NAME
FROM DBA_PDBS p, CDB_TABLES t
WHERE p.PDB_ID > 2 AND
t.OWNER = '&OWNER'
AND p.PDB_ID = t.CON_ID
ORDER BY p.PDB_ID
/


---- FEATURES USAGE STATISTICS
SET LINES 200 PAGES 2000
COL NAME FOR A60
COL CURRENTLY_USED FOR A15
SELECT DBID, NAME, VERSION, DETECTED_USAGES, TOTAL_SAMPLES, CURRENTLY_USED
FROM DBA_FEATURE_USAGE_STATISTICS
WHERE DETECTED_USAGES > 0
ORDER BY NAME
/

--- CHECK COMPONENTS STATISTICS
SET LINES 200 PAGES 2000
COL COMP_NAME FOR A35
COL VERSION FOR A35
COL STATUS FOR A35
SELECT COMP_NAME, VERSION, STATUS FROM DBA_REGISTRY
/

---- FEATURES USAGE STATISTICS (SQL TUNE, DIAGNOSTIC PACK)
set lines 200 pages 2000
col name for a60
select name, detected_usages, last_usage_date, last_sample_date
from dba_feature_usage_statistics
where name in (
    'ADDM', 'Automatic SQL Tuning Advisor', 'Automatic Workload Repository',
    'AWR Baseline', 'AWR Baseline Template', 'AWR Report', 'EM Performance Page',
    'Real-Time SQL Monitoring', 'SQL Access Advisor',
    'SQL Monitoring and Tuning pages', 'SQL Performance Analyzer',
    'SQL Tuning Advisor', 'SQL Tuning Set (system)', 'SQL Tuning Set (user)'
)
order by name
/

--- LISTAR O MESMO USUARIO EM TODOS OS PDBS - 12C (NAO LISTA USUARIOS NOS CDBS "CDB$ROOT & PDB$SEED")
COLUMN PDB_NAME FORMAT A15
COLUMN USERNAME FORMAT A30
SELECT p.PDB_ID, p.PDB_NAME, u.USERNAME
FROM DBA_PDBS p, CDB_USERS u
WHERE p.PDB_ID > 2
AND p.PDB_ID = u.CON_ID
AND u.USERNAME = '&USERNAME'
ORDER BY p.PDB_ID
/


--- VERIFICAR SESSÃO
SET LINES 200 PAGES 2000
SET LONG 999999999
ALTER SESSION SET NLS_DATE_FORMAT='DD/MM/YYYY HH24:MI:SS';
COL USERNAME FOR A12
COL EVENT FOR A35
COL MODULE FOR A15
SELECT INST_ID, SID, SERIAL#, USERNAME, PREV_SQL_ID, SQL_ID, MODULE, EVENT, STATUS, LOGON_TIME
FROM GV$SESSION
WHERE SID = '&SID'
ORDER BY LOGON_TIME
/


--- VERIFICAR STATUS USUÁRIO
COL USERNAME FOR A15
COL ACCOUNT_STATUS FOR A20
COL DEFAULT_TABLESPACE FOR A20
COL TEMPORARY_TABLESPACE FOR A20
COL PROFILE FOR A30
SELECT USERNAME, ACCOUNT_STATUS, CREATED, LOCK_DATE, EXPIRY_DATE, DEFAULT_TABLESPACE, TEMPORARY_TABLESPACE, PROFILE
FROM DBA_USERS
WHERE USERNAME = '&USERNAME'
/


--- IDENTIFICAR A SESSÃO DO USUÁRIO NA BASE DE DADOS, ATRAVÉS DO PROCESSO DO SISTEMA OPERACIONAL (ps -ef | grep)
SELECT S.SID, S.SERIAL#, P.SPID OS_PID, S.USERNAME, S.OSUSER, S.EVENT, S.LOGON_TIME
FROM V$PROCESS P, V$SESSION S
WHERE P.ADDR = S.PADDR
AND P.SPID = '&OS_PID'
/


--- MATAR SESSÃO DO USUÁRIO REMOTAMENTE: ORACLE RAC
SELECT 'ALTER SYSTEM KILL SESSION '''||SID||','||SERIAL#||','||'@'||INST_ID||''' IMMEDIATE;'
FROM GV$SESSION
WHERE OSUSER = '&OSUSER'
/

--- IDENTIFICAR SESSÕES (Distributed)
SELECT * FROM DBA_2PC_PENDING;
SELECT * FROM DBA_2PC_NEIGHBORS WHERE LOCAL_TRAN_ID = '193.24.582277';
ROLLBACK FORCE '193.24.582277';
or 
COMMIT FORCE '193.24.582277';
EXECUTE DBMS_TRANSACTION.PURGE_LOST_DB_ENTRY('193.24.582277');


--- COUNT QUANTIDADE DE PROCESSOS (V$PROCESS)
SELECT COUNT(1) PROCESS_CNT 
FROM V$PROCESS
/



--- VERIFICAR CONSUMO DAS TABLESPACES
COLUMN TABLESPACE FORMAT A30
COLUMN TOTAL_MB FORMAT 999,999,999,999.99
COLUMN USED_MB FORMAT 999,999,999,999.99
COLUMN FREE_MB FORMAT 999,999,999.99
COLUMN PCT_USED FORMAT 999.99
COLUMN GRAPH FORMAT A25 HEADING "GRAPH (X=5%)"
COLUMN STATUS FORMAT A10
COMPUTE SUM OF TOTAL_MB ON REPORT
COMPUTE SUM OF USED_MB ON REPORT
COMPUTE SUM OF FREE_MB ON REPORT
BREAK ON REPORT
SET LINES 200 PAGES 300
SELECT  TOTAL.TS TABLESPACE, DECODE(TOTAL.MB,NULL,'OFFLINE',DBAT.STATUS) STATUS
,TOTAL.MB TOTAL_MB,NVL(TOTAL.MB - FREE.MB,TOTAL.MB) USED_MB,NVL(FREE.MB,0) FREE_MB
,DECODE(TOTAL.MB,NULL,0,NVL(ROUND((TOTAL.MB - FREE.MB)/(TOTAL.MB)*100,2),100)) PCT_USED
,CASE WHEN (TOTAL.MB IS NULL) THEN '['||RPAD(LPAD('OFFLINE',13,'-'),20,'-')||']'ELSE '['|| DECODE(FREE.MB,NULL,'XXXXXXXXXXXXXXXXXXXX'
,NVL(RPAD(LPAD('X',TRUNC((100-ROUND( (FREE.MB)/(TOTAL.MB) * 100, 2))/5),'X'),20,'-'),'--------------------'))||']' END AS GRAPH
FROM (SELECT TABLESPACE_NAME TS, SUM(BYTES)/1024/1024 MB FROM DBA_DATA_FILES GROUP BY TABLESPACE_NAME) TOTAL
, (SELECT TABLESPACE_NAME TS, SUM(BYTES)/1024/1024 MB FROM DBA_FREE_SPACE GROUP BY TABLESPACE_NAME) FREE
, DBA_TABLESPACES DBAT WHERE TOTAL.TS=FREE.TS(+) AND TOTAL.TS=DBAT.TABLESPACE_NAME UNION ALL SELECT  SH.TABLESPACE_NAME, 'TEMP'
, SUM(SH.BYTES_USED+SH.BYTES_FREE)/1024/1024 TOTAL_MB, SUM(SH.BYTES_USED)/1024/1024 USED_MB, SUM(SH.BYTES_FREE)/1024/1024 FREE_MB
, ROUND(SUM(SH.BYTES_USED)/SUM(SH.BYTES_USED+SH.BYTES_FREE)*100,2) PCT_USED, '['||DECODE(SUM(SH.BYTES_FREE),0,'XXXXXXXXXXXXXXXXXXXX'
, NVL(RPAD(LPAD('X',(TRUNC(ROUND((SUM(SH.BYTES_USED)/SUM(SH.BYTES_USED+SH.BYTES_FREE))*100,2)/5)),'X'),20,'-'),'--------------------'))||']'
FROM V$TEMP_SPACE_HEADER SH GROUP BY TABLESPACE_NAME ORDER BY GRAPH
/


--- CONSUMO TABLESPACE (DONE BY ME), NAO TEM UNDO E NEM TEMP AQUI
SET LINES 200 PAGES 2000
COL TABLESPACE_NAME FOR A30
COL TOTAL_MB FOR A15
COL USED_MB FOR A15
COL FREE_MB FOR A15
SELECT U.TABLESPACE_NAME
, CASE WHEN U.USED_PERCENT < 1 THEN TO_CHAR(D.BYTES/1024/1024)
ELSE 
TO_CHAR(ROUND((U.TABLESPACE_SIZE * T.BLOCK_SIZE)/1024/1024))
END "TOTAL_MB"
, TO_CHAR((U.USED_SPACE * T.BLOCK_SIZE)/1024/1024, '999999999') "USED_MB"
, CASE WHEN U.USED_PERCENT < 1 THEN TO_CHAR(D.BYTES/1024/1024 - TO_CHAR((U.USED_SPACE * T.BLOCK_SIZE)/1024/1024, '999999999'))
ELSE 
TO_CHAR(((U.TABLESPACE_SIZE * T.BLOCK_SIZE)/1024/1024) - ((U.USED_SPACE * T.BLOCK_SIZE)/1024/1024), '999999999') 
END "FREE_MB"
, CASE WHEN U.USED_PERCENT < 1 THEN 0
ELSE TO_NUMBER(TO_CHAR(U.USED_PERCENT, '99'))
END "PCT_USED"
FROM DBA_TABLESPACES T, DBA_TABLESPACE_USAGE_METRICS U, DBA_DATA_FILES D
WHERE U.TABLESPACE_NAME = T.TABLESPACE_NAME
AND T.TABLESPACE_NAME = D.TABLESPACE_NAME
ORDER BY 5;



--- VERIFICAR SESSÕES EXECUTANDO PARALLEL
SELECT COUNT(S.SID), P.QCINST_ID, P.QCSID, P.QCSERIAL#, S.USERNAME, P.DEGREE, P.REQ_DEGREE, S.SQL_ID
FROM GV$PX_SESSION P , GV$SESSION S
WHERE P.QCSID = S.SID
AND P.QCSERIAL# = S.SERIAL#
GROUP BY  P.QCINST_ID, P.QCSID, P.QCSERIAL#, S.USERNAME, P.DEGREE, P.REQ_DEGREE, S.SQL_ID
ORDER BY 1
/

--- WAIT SESSIONS
COL USERNAME FOR A20
COL EVENT FOR A35
COL MODULE FOR A30
COL WAIT_CLASS FOR A25
SELECT INST_ID, SID, SERIAL#,USERNAME, BLOCKING_SESSION, BLOCKING_INSTANCE, EVENT, WAIT_CLASS, SECONDS_IN_WAIT, WAIT_TIME
FROM GV$SESSION WHERE STATE = 'WAITING'
AND WAIT_CLASS != 'Idle'
ORDER BY INST_ID, EVENT, WAIT_CLASS
/

--- COUNT WAIT SESSIONS
COL USERNAME FOR A20
COL EVENT FOR A45
COL MODULE FOR A30
SELECT COUNT(SID), INST_ID, MODULE, EVENT, WAIT_CLASS, SECONDS_IN_WAIT, WAIT_TIME
FROM GV$SESSION WHERE STATE = 'WAITING'
AND WAIT_CLASS != 'Idle'
GROUP BY INST_ID, MODULE, EVENT, WAIT_CLASS, SECONDS_IN_WAIT, WAIT_TIME
ORDER BY INST_ID, EVENT, WAIT_CLASS
/


--- CHECK DATAPATCH APPLIED 
SET LINES 200 PAGES 2000
COL ACTION_TIME FOR A30
COL DESCRIPTION FOR A60
SELECT  PATCH_ID, PATCH_UID, VERSION, STATUS, ACTION_TIME, DESCRIPTION
FROM DBA_REGISTRY_SQLPATCH
ORDER BY BUNDLE_SERIES
/

--- CHECK NLS DATABASE PARAMETERS
SET LINES 200 PAGES 2000
COL PARAMETER FOR A45
COL VALUE FOR A45
SELECT * FROM NLS_DATABASE_PARAMETERS
/

--- LISTAR USUÁRIO COM GRANT DBA
COL GRANTED_ROLE FOR A25
COL GRANTEE FOR A35
SELECT GRANTED_ROLE, GRANTEE, ADMIN_OPTION, DEFAULT_ROLE
FROM DBA_ROLE_PRIVS
WHERE GRANTEE IN (SELECT USERNAME FROM SYS.DBA_USERS)
AND GRANTED_ROLE = 'DBA'
ORDER BY GRANTED_ROLE, ADMIN_OPTION
/


--- SESSÃO COM LONGA OPERAÇÃO (Long Ops)
SELECT INST_ID, SID, SERIAL#, USERNAME, SQL_ID, OPNAME, SOFAR, TOTALWORK, TOTALWORK-SOFAR AS FALTAM, TIME_REMAINING
FROM GV$SESSION_LONGOPS
ORDER BY INST_ID
/


--- SESSÃO COM LONGA OPERAÇÃO (Long Ops) - SESSÃO ESPECÍFICA
SELECT INST_ID, SID, SERIAL#, USERNAME, SQL_ID, OPNAME, SOFAR, TOTALWORK, TOTALWORK-SOFAR AS FALTAM, TIME_REMAINING
FROM GV$SESSION_LONGOPS
WHERE SID = '&sid'
ORDER BY INST_ID
/


--- SESSÕES COM LONGA OPERAÇÃO (Long Ops) - TIME REMAINING
COLUMN SID FORMAT 99999
COLUMN SERIAL# FORMAT 9999999
COLUMN MACHINE FORMAT A30
COLUMN PROGRESS_PCT FORMAT 99999999.00
COLUMN ELAPSED FORMAT A10
COLUMN REMAINING FORMAT A10

SELECT S.SID,
       S.SERIAL#,
       S.MACHINE,
       ROUND(SL.ELAPSED_SECONDS/60) || ':' || MOD(SL.ELAPSED_SECONDS,60) ELAPSED,
       ROUND(SL.TIME_REMAINING/60) || ':' || MOD(SL.TIME_REMAINING,60) REMAINING,
       TO_CHAR(ROUND(SL.SOFAR/DECODE(SL.TOTALWORK, 0, 1,SL.TOTALWORK)*100, 2)) PROGRESS_PCT
FROM   V$SESSION S,
       V$SESSION_LONGOPS SL
WHERE  S.SID     = SL.SID
AND    S.SERIAL# = SL.SERIAL#
ORDER BY PROGRESS_PCT
/


--- GRANTS SISTEMA
SELECT GRANTEE, PRIVILEGE
FROM DBA_SYS_PRIVS
WHERE GRANTEE = '&USERNAME'
/


--- GRANTS TABLE
SELECT GRANTEE, OWNER, GRANTOR, TABLE_NAME, PRIVILEGE
FROM DBA_TAB_PRIVS
WHERE GRANTEE = '&USERNAME'
/



--- GRANT ROLE
SELECT GRANTEE, GRANTED_ROLE
FROM DBA_ROLE_PRIVS
WHERE GRANTEE = '&USERNAME'
/


--- INDEX UNUSABLE
SELECT OWNER, INDEX_NAME, INDEX_TYPE, TABLE_OWNER, TABLE_NAME, STATUS
FROM DBA_INDEXES
WHERE STATUS NOT IN ('VALID')
AND OWNER NOT IN ('SYS','SYSTEM')
/


--- CHECAR PARÂMETROS OCULTOS QUE ESTÃO CONFIGURADOS NA BASE DE DADOS (RODAR EM CADA INSTÂNCIA)
select name,value from v$parameter where substr(name,1,1)='_';

--- VERIFICAR CONSUMO TABLESPACE (CRIADO POR MIM.)
SET LINES 200 PAGES 2000
COL TABLESPACE_NAME FOR A35
COL TOTAL_MB FOR A15
COL USED_MB FOR A15
COL FREE_MB FOR A15
COL USED_PCT FOR A10
COL FREE_PCT FOR A10
SELECT D.TABLESPACE_NAME
, TO_CHAR(ROUND(SUM(D.BYTES/1024/1024))) AS TOTAL_MB
, TO_CHAR(ROUND(SUM(D.BYTES - F.BYTES)/1024/1024)) AS USED_MB
, TO_CHAR(ROUND(SUM(F.BYTES/1024/1024))) AS FREE_MB
, TO_CHAR(ROUND(SUM(D.BYTES - F.BYTES)/1024/1024) / ROUND(SUM(D.BYTES/1024/1024)) * 100, '00.00')  AS USED_PCT
, TO_CHAR(100 - (ROUND(SUM(D.BYTES - F.BYTES)/1024/1024)) / ROUND(SUM(D.BYTES/1024/1024)) * 100, '00.00')  AS FREE_PCT
FROM  DBA_DATA_FILES D, DBA_FREE_SPACE F
WHERE D.FILE_ID = F.FILE_ID
GROUP BY D.TABLESPACE_NAME
ORDER BY USED_PCT
/

--- VERIFICAR QUANDO OS DATAFILES FORAM CRIADOS E/OU MODIFICADOS
COL AUTOEXTENSIBLE FOR A20
COL FILE_NAME FOR A80
SELECT DISTINCT(D.FILE#), F.FILE_NAME, D.CREATION_CHANGE#, D.CREATION_TIME, D.LAST_CHANGE#, D.LAST_TIME, D.STATUS, F.AUTOEXTENSIBLE
FROM V$DATAFILE D, V$TABLESPACE T, DBA_DATA_FILES F
WHERE D.TS# = T.TS#
AND T.NAME = '&TABLESPACE_NAME'
ORDER BY 1,2,3
/


--- GERAR SCRIPT RESIZE NEGATIVO DATAFILE (DOWNSIZE)
SET LINESIZE 1000 PAGESIZE 0 FEEDBACK OFF TRIMSPOOL ON
WITH
 HWM AS (
  -- GET HIGHEST BLOCK ID FROM EACH DATAFILES ( FROM X$KTFBUE AS WE DON'T NEED ALL JOINS FROM DBA_EXTENTS )
  SELECT /*+ MATERIALIZE */ KTFBUESEGTSN TS#,KTFBUEFNO RELATIVE_FNO,MAX(KTFBUEBNO+KTFBUEBLKS-1) HWM_BLOCKS
  FROM SYS.X$KTFBUE GROUP BY KTFBUEFNO,KTFBUESEGTSN
 ),
 HWMTS AS (
  -- JOIN TS# WITH TABLESPACE_NAME
  SELECT NAME TABLESPACE_NAME,RELATIVE_FNO,HWM_BLOCKS
  FROM HWM JOIN V$TABLESPACE USING(TS#)
 ),
 HWMDF AS (
  -- JOIN WITH DATAFILES, PUT 50M MINIMUM FOR DATAFILES WITH NO EXTENTS
  SELECT FILE_NAME,NVL(HWM_BLOCKS*(BYTES/BLOCKS),50*1024*1024) HWM_BYTES,BYTES,AUTOEXTENSIBLE,MAXBYTES
  FROM HWMTS RIGHT JOIN DBA_DATA_FILES USING(TABLESPACE_NAME,RELATIVE_FNO)
 )
SELECT
 CASE WHEN AUTOEXTENSIBLE='YES' AND MAXBYTES>=BYTES
 THEN -- WE GENERATE RESIZE STATEMENTS ONLY IF AUTOEXTENSIBLE CAN GROW BACK TO CURRENT SIZE
  '/* RECLAIM '||TO_CHAR(CEIL((BYTES-HWM_BYTES)/1024/1024),999999)
   ||'M FROM '||TO_CHAR(CEIL(BYTES/1024/1024),999999)||'M */ '
   ||'ALTER DATABASE DATAFILE '''||FILE_NAME||''' RESIZE '||CEIL(HWM_BYTES/1024/1024)||'M;'
 ELSE -- GENERATE ONLY A COMMENT WHEN AUTOEXTENSIBLE IS OFF
  '/* RECLAIM '||TO_CHAR(CEIL((BYTES-HWM_BYTES)/1024/1024),999999)
   ||'M FROM '||TO_CHAR(CEIL(BYTES/1024/1024),999999)
   ||'M AFTER SETTING AUTOEXTENSIBLE MAXSIZE HIGHER THAN CURRENT SIZE FOR FILE '
   || FILE_NAME||' */'
 END SQL
FROM HWMDF
WHERE
 BYTES-HWM_BYTES>1024*1024 -- RESIZE ONLY IF AT LEAST 1MB CAN BE RECLAIMED
ORDER BY BYTES-HWM_BYTES DESC
/



--- VERIFICAR BLOCOS CORROMPIDOS
COL FILE_NAME FOR A60
COL TABLESPACE_NAME FOR A20
SELECT D.FILE_ID, D.FILE_NAME, D.TABLESPACE_NAME, C.BLOCKS, C.BLOCK#, C.CORRUPTION_CHANGE#, C.CORRUPTION_TYPE, D.BYTES/1024/1024 AS MB, D.STATUS
FROM DBA_DATA_FILES D, V$DATABASE_BLOCK_CORRUPTION C
WHERE D.FILE_ID = C.FILE#
AND D.BLOCKS = C.BLOCKS
ORDER BY 1,2
/


--- OBJETOS INVALIDOS
COL OBJECT_NAME FOR A40
COL LAST_DDL_TIME FOR A30
SELECT OWNER, OBJECT_NAME, OBJECT_TYPE, LAST_DDL_TIME, STATUS
FROM DBA_OBJECTS
WHERE STATUS NOT IN ('VALID')
ORDER BY OWNER, LAST_DDL_TIME
/


--- COMPILAR OBJETOS INVALIDOS
SELECT 'ALTER '||REPLACE(OBJECT_TYPE,'PACKAGE BODY','PACKAGE')||' '||OWNER||'.'||OBJECT_NAME||' COMPILE;'
FROM DBA_OBJECTS
WHERE STATUS NOT IN ('VALID')
ORDER BY OBJECT_TYPE
/

--- COMPILAR OBJETOS INVALIDOS (EXECUTE IMMEDIATE)
DECLARE
  SQL_TEXT VARCHAR2(1000);
BEGIN
  FOR REG IN (
    SELECT 'ALTER '||OBJECT_TYPE||' '||OWNER||'.'||OBJECT_NAME||' COMPILE' CMD
    FROM DBA_OBJECTS WHERE STATUS NOT IN ('VALID') ORDER BY OBJECT_TYPE
)
   LOOP
    BEGIN
      SQL_TEXT := REG.CMD;
      DBMS_OUTPUT.PUT_LINE(SQL_TEXT);
      EXECUTE IMMEDIATE SQL_TEXT;
    END;
  END LOOP;
END;
/



--- VERIFICAR LOBS DE UMA TABELA ESPECÍFICA
COL OWNER FOR A10
COL COLUMN_NAME FOR A20
SELECT OWNER, TABLE_NAME, COLUMN_NAME, SEGMENT_NAME, TABLESPACE_NAME, INDEX_NAME, COMPRESSION, DEDUPLICATION, PARTITIONED, SECUREFILE
FROM DBA_LOBS
WHERE TABLE_NAME = '&TABLE_NAME'
/

--- VERIFICAR LOBS SUBPARTITIONS
SELECT TABLE_OWNER, TABLE_NAME, LOB_PARTITION_NAME, SUBPARTITION_NAME, TABLESPACE_NAME, COMPRESSION, SECUREFILE
FROM DBA_LOB_SUBPARTITIONS
WHERE TABLE_NAME = '&TABLE_NAME'
ORDER BY 4,5
/


--- VERIFICAR TAMANHO PARTIÇÕES LOB
COL SEGMENT_NAME FOR A25
COL PARTITION_NAME FOR A20
COL SUBPARTITION_NAME FOR A25
SELECT PARTITION_NAME, BYTES/1024/1024 AS TOTAL_MB
FROM DBA_SEGMENTS
WHERE SEGMENT_NAME IN (SELECT SEGMENT_NAME FROM DBA_LOBS WHERE OWNER = '&OWNER' AND TABLE_NAME = '&TABLE_NAME')
ORDER BY 2
/


--- VERIFICAR TAMANHO DE TODAS AS PARTIÇÕES E SUBPARTIÇÕES LOB
COL SEGMENT_NAME FOR A25
COL PARTITION_NAME FOR A20
COL SUBPARTITION_NAME FOR A25
COL LOB_SUBPARTITION_NAME FOR A25
SELECT S.SEGMENT_NAME, S.SEGMENT_TYPE, T.PARTITION_NAME AS TABLE_PARTITION_NAME, T.SUBPARTITION_NAME, L.LOB_SUBPARTITION_NAME, S.BYTES/1024/1024 AS MB
FROM DBA_SEGMENTS S, DBA_LOB_SUBPARTITIONS L, DBA_TAB_SUBPARTITIONS T
WHERE S.PARTITION_NAME = L.LOB_SUBPARTITION_NAME
AND S.SEGMENT_NAME IN (SELECT SEGMENT_NAME FROM DBA_LOBS WHERE TABLE_NAME = '&TABLE_NAME' AND OWNER = '&OWNER')
ORDER BY 3,4,5,6
/


--- GET DDL USER
SET LONG 200000
SET PAGES 10000
SET LINESIZE 2000
COL DDL FOR A2000
SET TRIMSPOOL ON
SELECT DBMS_METADATA.GET_DDL('USER','&USERNAME') FROM DUAL
/


--- GET DDL PROFILE
SET LONG 200000
SET PAGES 10000
SET LINESIZE 2000
COL DDL FOR A2000
SET TRIMSPOOL ON
SELECT DBMS_METADATA.GET_DDL('PROFILE','&PROFILE_NAME') FROM DUAL
/


--- GET DDL TABLE
SET LONG 200000
SET PAGES 10000
SET LINESIZE 2000
COL DDL FOR A2000
SET TRIMSPOOL ON
SELECT DBMS_METADATA.GET_DDL('TABLE','&TABLE_NAME','&OWNER') FROM DUAL
/


--- GET DDL PACKAGE
SET LONG 200000
SET PAGES 10000
SET LINESIZE 2000
COL DDL FOR A2000
SET TRIMSPOOL ON
SELECT DBMS_METADATA.GET_DDL('PACKAGE','&PACKAGE_NAME','&OWNER') FROM DUAL
/

--- GET DDL PACKAGE_BODY
SET LONG 200000
SET PAGES 10000
SET LINESIZE 2000
COL DDL FOR A2000
COL TXT FOR A300 WORD_WRAPPED
SET TRIMSPOOL ON
SELECT DBMS_METADATA.GET_DDL('PACKAGE_BODY','&PACKAGE_NAME','&OWNER') TXT FROM DUAL
/



--- GET DDL INDEX
SET LONG 200000
SET PAGES 10000
SET LINESIZE 2000
COL DDL FOR A2000
SET TRIMSPOOL ON
SELECT DBMS_METADATA.GET_DDL('INDEX','&INDEX_NAME','&OWNER') FROM DUAL
/


--- GET DDL PROCEDURE
SET LONG 200000
SET PAGES 10000
SET LINESIZE 2000
COL DDL FOR A2000
SET TRIMSPOOL ON
SELECT DBMS_METADATA.GET_DDL('PROCEDURE','&PROCEDURE_NAME','&OWNER') FROM DUAL
/


--- GET DDL TRIGGER
SET LONG 200000
SET PAGES 10000
SET LINESIZE 2000
COL DDL FOR A2000
SET TRIMSPOOL ON
SELECT DBMS_METADATA.GET_DDL('TRIGGER','&TRIGGER_NAME','&OWNER') FROM DUAL
/


--- GET DDL SYNONYM
SET LONG 200000
SET PAGES 10000
SET LINESIZE 2000
COL DDL FOR A2000
SET TRIMSPOOL ON
SELECT DBMS_METADATA.GET_DDL('SYNONYM','&SYNONYM_NAME','&OWNER') FROM DUAL
/


--- GET DDL DB_LINK
SET LONG 200000
SET PAGES 10000
SET LINESIZE 2000
COL DDL FOR A2000
SET TRIMSPOOL ON
SELECT DBMS_METADATA.GET_DDL('DB_LINK','&DB_LINK', '&OWNER') FROM DUAL
/



--- GET DDL FUNCTION
SET LONG 200000
SET PAGES 10000
SET LINESIZE 2000
COL DDL FOR A2000
SET TRIMSPOOL ON
SELECT DBMS_METADATA.GET_DDL('FUNCTION','&FUNCTION_NAME', '&OWNER') FROM DUAL
/



--- GET DDL VICTOR LACERDA
/*
getddlpkg owner object
Ele retorna o spec e o body, concatenado, no mesmo arquivo
Parametro 1: owner
Parametro 2: package name
Spool será gravado no c:\temp
*/

set pages 0 heading off feedback off trimspool on lines 1000 termout off verify off
spool "c:\temp\&1..&2..ddl.sql"
SELECT text
FROM dba_source
WHERE upper(name) = upper('&2')
AND upper(owner) = upper('&1')
ORDER BY owner, name, type, line
/
spool off
set pages 200 heading on feedback on trimspool off lines 150 termout on


---------------------------------------------------------------------------------------------------------#



--- VERIFICAR ALERTAS DA BASE DE DADOS "DBA_OUTSTANDING_ALERTS":
COL HOST_ID FOR A30
COL REASON FOR A60
SELECT REASON , METRIC_VALUE , MESSAGE_TYPE , TO_CHAR(CREATION_TIME,'DD/MM/YYYY HH24:MI:SS') , HOST_ID FROM SYS.DBA_OUTSTANDING_ALERTS
ORDER BY CREATION_TIME
/


--- CAPTURAR GRANTS DO USUARIO
SELECT 'GRANT ' || PRIVILEGE || ' TO ' || GRANTEE || ';'
FROM DBA_SYS_PRIVS
WHERE GRANTEE = UPPER('&GRANTEE')
/


--- CAPTURAR GRANTS ROLE PARA USUARIO
SELECT 'GRANT ' || GRANTED_ROLE || ' TO ' || GRANTEE || ';'
FROM DBA_ROLE_PRIVS
WHERE GRANTEE = UPPER('&GRANTEE')
/


--- GERAR PLANO DE EXECUÇÃO DE QUERY
EXPLAIN PLAN FOR
EX.: SELECT SYSDATE FROM DUAL;
SELECT PLAN_TABLE_OUTPUT FROM TABLE(DBMS_XPLAN.DISPLAY())
/


--- CHECAR JOBS DBA_SCHEDULER_JOBS
COL OWNER FOR A15
COL JOB_NAME FOR A30
COL SCHEDULE_NAME FOR A10
COL REPEAT_INTERVAL FOR A30
COL LAST_START_DATE FOR A40
COL NEXT_RUN_DATE FOR A40
COL ENABLED FOR A10
SELECT OWNER, JOB_NAME, SCHEDULE_NAME, REPEAT_INTERVAL, LAST_START_DATE, NEXT_RUN_DATE, ENABLED
FROM DBA_SCHEDULER_JOBS
WHERE JOB_NAME = '&JOB_NAME'
/

--- HABILITAR JOBS DBA_SCHEDULER_JOBS
EXEC DBMS_SCHEDULER.ENABLE('&JOB_NAME');


--- DESABILITAR JOBS DBA_SCHEDULER_JOBS
EXEC DBMS_SCHEDULER.DISABLE('&JOB_NAME');

--- GERAR GRANT SELECT TABLE PARA USUÁRIO ESPECÍFICO
SELECT 'GRANT SELECT ON '||OWNER||'.'||TABLE_NAME||' TO &USER_RECEBE_GRANT;'
FROM DBA_TABLES
WHERE OWNER = '&OWNER_TABLE'
/



--- CHECAR SE PARÂMETRO É OU NÃO MODIFICADO ONLINE
SET LINES 200 PAGES 2000
COL NAME FOR A30
COL VALUE FOR A30
COL DISPLAY_VALUE FOR A30
COL ISSES_MODIFIABLE FOR A10
COL ISSYS_MODIFIABLE FOR A10
SELECT NAME, VALUE, DISPLAY_VALUE, ISSES_MODIFIABLE , ISSYS_MODIFIABLE
FROM V$PARAMETER
WHERE NAME LIKE '%&NAME%'
/



--- VERIFICAR SESSÃO DE USUÁRIO COM MAIS TEMPO DE CPU
set echo off
set feedback off
set linesize 512

prompt
prompt Top Sessions by CPU consumption
prompt

column sid                           heading "SID"
column username        format a20     heading "User Name"
column command        format a20     heading "Command"
column osuser        format a20     heading "OS User"
column machine        format a35     heading "Machine"
column spid            format a15        heading "OS_PROCESS"
column value        format 9999,9999  heading "CPU Time"


select
    s.sid        sid,
    s.serial#    serial#,
    s.username    username,
    UPPER(DECODE(command,
        1,'Create Table',2,'Insert',3,'Select',
        4,'Create Cluster',5,'Alter Cluster',6,'Update',
        7,'Delete', 8,'Drop Cluster', 9,'Create Index',
        10,'Drop Index', 11,'Alter Index', 12,'Drop Table',
        13,'Create Sequencfe', 14,'Alter Sequence', 15,'Alter Table',
        16,'Drop Sequence', 17,'Grant', 18,'Revoke',
        19,'Create Synonym', 20,'Drop Synonym', 21,'Create View',
        22,'Drop View', 23,'Validate Index', 24,'Create Procedure',
        25,'Alter Procedure', 26,'Lock Table', 27,'No Operation',
        28,'Rename', 29,'Comment', 30,'Audit',
        31,'NoAudit', 32,'Create Database Link', 33,'Drop Database Link',
        34,'Create Database', 35,'Alter Database', 36,'Create Rollback Segment',
        37,'Alter Rollback Segment', 38,'Drop Rollback Segment', 39,'Create Tablespace',
        40,'Alter Tablespace', 41,'Drop Tablespace', 42,'Alter Sessions',
        43,'Alter User', 44,'Commit', 45,'Rollback',
        46,'Savepoint', 47,'PL/SQL Execute', 48,'Set Transaction',
        49,'Alter System Switch Log', 50,'Explain Plan', 51,'Create User',
        52,'Create Role', 53,'Drop User', 54,'Drop Role',
        55,'Set Role', 56,'Create Schema', 57,'Create Control File',
        58,'Alter Tracing', 59,'Create Trigger', 60,'Alter Trigger',
        61,'Drop Trigger', 62,'Analyze Table', 63,'Analyze Index',
        64,'Analyze Cluster', 65,'Create Profile', 66,'Drop Profile',
        67,'Alter Profile', 68,'Drop Procedure', 69,'Drop Procedure',
        70,'Alter Resource Cost', 71,'Create Snapshot Log', 72,'Alter Snapshot Log',
        73,'Drop Snapshot Log', 74,'Create Snapshot', 75,'Alter Snapshot',
        76,'Drop Snapshot', 79,'Alter Role', 85,'Truncate Table',
        86,'Truncate Cluster', 88,'Alter View', 91,'Create Function',
        92,'Alter Function', 93,'Drop Function', 94,'Create Package',
        95,'Alter Package', 96,'Drop Package', 97,'Create Package Body',
        98,'Alter Package Body', 99,'Drop Package Body')) command,
    s.osuser    osuser,
    s.prev_sql_id,
    s.sql_id,
    s.machine    machine,
    p.spid,
    t.value        value
from
    v$session s,
    v$sesstat t,
    v$statname n,
    v$process p
where
    s.sid = t.sid
    and
    s.paddr = p.addr
    and   
    t.statistic# = n.statistic#
    and
    n.name = 'CPU used by this session'
    and
    t.value > 0
    and
    audsid > 0
order by
    t.value;

---------------------------------------------------------------------------------------------------------------------------------#


--- LISTAR TAMANHO DAS PRINCIPAIS ÁREAS DE MEMÓRIA DO DATABASE
set echo off
set feedback off
set linesize 512

prompt
prompt SGA Memory Map (overall)
prompt

column dummy      noprint
column area       format a20 heading 'Main SGA Areas'
column name       format a20
column pool       format a20
column bytes      format 999 heading 'Total_MB'
column sum(bytes) format 999 heading 'Total_MB'

break on report
compute sum of sum(bytes) on report

SELECT 1 dummy, 'DB Buffer Cache' area, name, sum(bytes/1024/1024) as Total_MB
FROM v$sgastat
WHERE pool is null and
      name = 'db_block_buffers'
group by name
union all
SELECT 2, 'Shared Pool', pool, sum(bytes/1024/1024) as Total_MB
FROM v$sgastat
WHERE pool = 'shared pool'
group by pool
union all
SELECT 3, 'Large Pool', pool, sum(bytes/1024/1024) as Total_MB
FROM v$sgastat
WHERE pool = 'large pool'
group by pool
union all
SELECT 4, 'Java Pool', pool, sum(bytes/1024/1024) as Total_MB
FROM v$sgastat
WHERE pool = 'java pool'
group by pool
union all
SELECT 5, 'Redo Log Buffer', name, sum(bytes/1024/1024) as Total_MB
FROM v$sgastat
WHERE pool is null and
      name = 'log_buffer'
group by name
union all
SELECT 6, 'Fixed SGA', name, sum(bytes/1024/1024) as Total_MB
FROM v$sgastat
WHERE pool is null and
      name = 'fixed_sga'
group by name
ORDER BY 4 desc;


column area       format a20 heading 'Shared Pool Areas'

prompt
prompt SGA Memory Map (shared pool)
prompt

SELECT 'Shared Pool' area, name, sum(bytes/1024/1024) as Total_MB
FROM v$sgastat
WHERE pool = 'shared pool' and
      name in ('library cache','dictionary cache','free memory','sql area')
group by name
union all
SELECT 'Shared Pool' area, 'miscellaneous', sum(bytes/1024/1024) as Total_MB
FROM v$sgastat
WHERE pool = 'shared pool' and
      name not in ('library cache','dictionary cache','free memory','sql area')
group by pool
order by 3 desc;

---------------------------------------------------------------------------------------------------------------------------------#


--- GERAR SCRIPT DE RENAME FILE (RMAN)
SELECT '"ALTER DATABASE RENAME FILE ''''' || NAME || '''''' || ' TO ' || '''''' || REPLACE(NAME, '+DG_12C_DATA/CDB12C', '+DG_STDB12C_DATA/CDBSTDB') || ''''' ";' FROM V$DATAFILE
/

SELECT '"ALTER DATABASE RENAME FILE ''''' || NAME || '''''' || ' TO ' || '''''' || REPLACE(NAME, '+DG_12C_DATA/CDB12C', '+DG_STDB12C_DATA/CDBSTDB') || ''''' ";' FROM V$TEMPFILE
/

SELECT '"ALTER DATABASE RENAME FILE ''''' || MEMBER || '''''' || ' TO ' || '''''' || REPLACE(MEMBER, '+DG_12C_REDO/CDB12C', '+DG_STDB12C_REDO/CDBSTDB') || ''''' ";' FROM V$LOGFILE
/


--- GERAR SCRIPT DE SET NEWNAME (RMAN)
SELECT 'SET NEWNAME FOR DATAFILE ' || FILE# || ' TO ' || '''' || REPLACE(NAME, '+DG_12C_DATA/CDB12C', '+DG_STDB12C_DATA/CDBSTDB') || ''';' FROM V$DATAFILE
/

SELECT 'SET NEWNAME FOR TEMPFILE ' || FILE# || ' TO ' || '''' || REPLACE(NAME, '+DG_12C_DATA/CDB12C', '+DG_STDB12C_DATA/CDBSTDB') || ''';' FROM V$TEMPFILE
/

SELECT ' SQL "ALTER DATABASE RENAME FILE ''''' || MEMBER || '''''' || ' TO ' || '''''' || REPLACE(MEMBER, '+DG_12C_REDO/CDB12C', '+DG_STDB12C_REDO/CDBSTDB') || ''''' ";' FROM V$LOGFILE
/




--- CRIAR SYNONYMS PARA USUÁRIO ESPECÍFICO
SELECT 'CREATE OR REPLACE SYNONYM &USER_RECEBE_SYNONYM'||'.'||TABLE_NAME||' FOR '||OWNER||'.'||TABLE_NAME||';'
FROM DBA_TABLES
WHERE OWNER = '&OWNER_TABLE'
/


--- LISTAR USUÁRIOS QUE NÃO SÃO DE SISTEMA
COL TEMPORARY_TABLESPACE FOR A15
COL DEFAULT_TABLESPACE FOR A20
COL USERNAME FOR A20
COL PROFILE FOR A30
SELECT USERNAME, ACCOUNT_STATUS, PROFILE, DEFAULT_TABLESPACE, TEMPORARY_TABLESPACE, CREATED FROM DBA_USERS
WHERE USERNAME NOT IN ('OWBSYS_AUDIT' ,'AUDSYS' ,'SYSBACKUP' ,'SYSKM' ,'SYSDG' ,'GSMADMIN_INTERNAL' ,'GSMUSER' ,'GSMCATUSER' ,'OJVMSYS' ,'LBACSYS' ,'APEX_040200' ,'DVSYS' ,'DVF','DIP', 'DMSYS', 'TSMSYS','XS$NULL' ,'MDSYS' ,'SPATIAL_WFS_ADMIN_USR' ,'SPATIAL_CSW_ADMIN_USR' ,'OLAPSYS' ,'OWBSYS' ,'CTXSYS' ,'FLOWS_FILES' ,'MGMT_VIEW' ,'OUTLN' ,'ORACLE_OCM' ,'SCOTT' ,'APEX_030200' ,'EXFSYS' ,'SYSTEM' ,'APEX_PUBLIC_USER' ,'MDDATA' ,'ORDPLUGINS' ,'SYSMAN' ,'ORDSYS' ,'DBSNMP' ,'XDB' ,'ORDDATA' ,'APPQOSSYS' ,'SI_INFORMTN_SCHEMA' ,'ANONYMOUS' ,'WMSYS' ,'SYS')
/



--- VERIFICAR CONSUMO DB_RECOVERY_FILE_DEST
COL NAME FOR A40
COL SIZE_M FOR 999,999,999
COL USED_M FOR 999,999,999
COL PCT_USED FOR 999
SELECT NAME
,CEIL( SPACE_LIMIT / 1024 / 1024) SIZE_M
,CEIL( SPACE_USED  / 1024 / 1024) USED_M
,DECODE( NVL( SPACE_USED, 0), 0, 0
, CEIL ( ( SPACE_USED / SPACE_LIMIT) * 100) ) PCT_USED
FROM V$RECOVERY_FILE_DEST
ORDER BY NAME
/

--- VERIFICAR QUAIS TIPOS DE ARQUIVOS ESTÃO CONSUMINDO MAIS NO: DB_RECOVERY_FILE_DEST
SET LINES 200 PAGES 2000
SELECT * FROM V$FLASH_RECOVERY_AREA_USAGE
/


---VERIFICAR HISTORY STARTUP/SHUTDOWN DA BASE DE DADOS
COL STARTUP_TIME FOR A30
SELECT DBID, INSTANCE_NUMBER, STARTUP_TIME, VERSION, DB_NAME, INSTANCE_NAME
FROM DBA_HIST_DATABASE_INSTANCE
ORDER BY STARTUP_TIME
/



--- REALIZAR EXPORT E IMPORT DE OBJETO ESPECÍFICO DO DATABASE:
expdp \'/ as sysdba\' DIRECTORY=LEO DUMPFILE=leo_test.dmp LOGFILE=leo_test.log CONTENT=METADATA_ONLY SCHEMAS=AGENDA INCLUDE=FUNCTION:"IN('F_GETHASH')";

impdp \'/ as sysdba\' DIRECTORY=LEO DUMPFILE=leo_test.dmp LOGFILE=leo_test.log SCHEMAS=AGENDA INCLUDE=FUNCTION:"IN('F_GETHASH')";


--- VERIFICAR ALTERAÇÃO OBJETOS NOS ÚLTIMOS DIAS
SET LINESIZE 200;
SET PAGESIZE 100;
SET HEADING ON;
COLUMN OWNER FORMAT A15
COLUMN OBJECT_NAME FORMAT A25
COLUMN OBJECT_TYPE FORMAT A10
SELECT OWNER, OBJECT_NAME, OBJECT_TYPE, CREATED, LAST_DDL_TIME, TIMESTAMP,STATUS FROM DBA_OBJECTS
WHERE (CREATED>=SYSDATE-7 OR LAST_DDL_TIME>=SYSDATE-7) AND OWNER NOT IN ('SYS','SYSTEM','SYSMAN','DBSNMP')
ORDER BY LAST_DDL_TIME DESC
/

--- VERIFICAR WAIT TIME E EVENTO SESSÃO ESPECÍFICA
COL WAIT_CLASS FOR A15
COL EVENT FOR A40
COL USERNAME FOR A18
COL SQL_ADDRESS FOR A18
COL SQL_ID FOR A18
SELECT S.SID, S.SERIAL#, S.USERNAME, S.SQL_ID, S.SQL_ADDRESS, W.WAIT_CLASS, C.TOTAL_WAITS, C.TIME_WAITED, S.LOGON_TIME, S.EVENT, S.STATUS
FROM V$SESSION S, V$SESSION_WAIT W, V$SESSION_WAIT_CLASS C
WHERE S.SID = W.SID
AND W.SID = C.SID
AND S.SID = '&SID'
ORDER BY LOGON_TIME
/



--- LISTAR TABLESPACE BASEADO NO AUTOEXTEND
select
a.tablespace_name,
a.bytes / 1024 / 1024 file_size,
(a.bytes - nvl(b.total_free,0)) /1024/1024 used,
nvl(b.total_free,0) / 1024 / 1024 total_free,
100 - (nvl(b.total_free,0) / a.bytes * 100) pct_full,
a.mb/1024/1024 Auto_extend,
(total_free + ab)/1024/1024 auto_free,
100 - ((nvl(b.total_free,0)+ decode(mb,0,0,ab)) / decode(a.mb,0,a.bytes,a.mb) * 100) autopct_fu
from
   (
   select
   tablespace_name,
   sum(bytes) bytes,
   sum(decode(maxbytes,0,bytes,greatest(maxbytes,bytes)))mb,
   sum(decode(maxbytes,0,bytes,greatest(maxbytes,bytes))-bytes)ab
   from
   dba_data_files
   group by tablespace_name
   ) a,
   (
   select tablespace_name,sum(bytes) total_free
   from
           (
           select tablespace_name, bytes from dba_free_space
           union
           select distinct tablespace_name, 0 bytes from dba_tablespaces
           )
group by tablespace_name
) b
where a.tablespace_name = b.tablespace_name
/



--- LISTAR SNAPSHOTS AWR
SELECT SNAP_ID, SNAP_LEVEL, TO_CHAR(BEGIN_INTERVAL_TIME, 'DD/MM/YY HH24:MI:SS') BEGIN
FROM DBA_HIST_SNAPSHOT
ORDER BY 1
/



--- VERIFICAR STATUS SEGMENT UNDO / ROLLBACK
SELECT OWNER, SEGMENT_NAME, TABLESPACE_NAME, FILE_ID, STATUS
FROM DBA_ROLLBACK_SEGS
WHERE STATUS <> 'ONLINE'
/

---
SELECT 'ALTER ROLLBACK SEGMENT '||'"'|| SEGMENT_NAME ||'"'||' ONLINE;'
FROM DBA_ROLLBACK_SEGS
WHERE STATUS <> 'ONLINE'
/


--- SEGMENTO UNDO / ROLLBACK - DEIXAR ONLINE
ALTER ROLLBACK SEGMENT "XXXXX" ONLINE



--- CHECK FOREIGN KEYS OWNER ESPECÍFICO
COL COLUMN_NAME FOR A30
SELECT A.R_OWNER OWNER, A.TABLE_NAME TABLE_NAME, 'CONSTRAINT' CLASS, A.CONSTRAINT_NAME NAME, B.POSITION POSITION,
B.COLUMN_NAME COLUMN_NAME
FROM DBA_CONSTRAINTS A, DBA_CONS_COLUMNS B
WHERE A.CONSTRAINT_NAME = B.CONSTRAINT_NAME
AND A.CONSTRAINT_TYPE = 'R'
AND B.OWNER = UPPER('&USERNAME')
ORDER BY 1
/

--- SESSÕES NO PASSADO
COL MACHINE FOR A35
COL EVENT FOR A35
COL USERNAME FOR A20
COL SQL_ADDRESS FOR A20
SELECT DISTINCT(A.SESSION_ID), A.SESSION_SERIAL#, B.USERNAME, A.SQL_ID, A.MACHINE, B.LOGON_TIME, A.EVENT
FROM V$ACTIVE_SESSION_HISTORY A, V$SESSION B
WHERE A.SESSION_ID = B.SID
AND A.SESSION_SERIAL# = B.SERIAL#
ORDER BY B.LOGON_TIME
/



--- VERIFICAR LOCK BANCO
COL MACHINE FOR A20
COL MODULE FOR A25
COL EVENT FOR A25
COL ACTION FOR A20
COL SQL_ADDRESS FOR A20
COL CLIENT_INFO FOR A20
COL OBJECT_NAME FOR A10
COL OBJECT_TYPE FOR A10
SELECT /*+ RULE */ DISTINCT(D.SESSION_ID) SID_BLOQUEADOR, A.SESSION_ID AS BLOQUEADO, A.SESSION_SERIAL#, A.SQL_ID, B.SQL_ADDRESS, O.OBJECT_TYPE, O.OBJECT_NAME, A.MODULE, B.MACHINE, B.LOGON_TIME, A.EVENT
FROM V$ACTIVE_SESSION_HISTORY A, V$SESSION B, DBA_OBJECTS O, V$LOCKED_OBJECT L, V$LOCK K, DBA_LOCKS D
WHERE A.SESSION_ID = B.SID
AND B.SID = L.SESSION_ID
AND O.OBJECT_ID = L.OBJECT_ID
AND D.BLOCKING_OTHERS = 'Blocking'
AND A.EVENT LIKE '%contention%'
ORDER BY B.LOGON_TIME
/


--- CHECAR HISTORY LOCK PASSADO
COL MACHINE FOR A20
COL MODULE FOR A25
COL EVENT FOR A40
COL ACTION FOR A20
COL SQL_ADDRESS FOR A20
COL CLIENT_INFO FOR A20
SELECT DISTINCT(A.SESSION_ID), A.SESSION_SERIAL#, A.SQL_ID, B.SQL_ADDRESS, B.ACTION, B.CLIENT_INFO, A.MODULE, A.MACHINE, B.LOGON_TIME, A.EVENT
FROM V$ACTIVE_SESSION_HISTORY A, V$SESSION B
WHERE A.SESSION_ID = B.SID
AND A.SESSION_SERIAL# = B.SERIAL#
AND A.EVENT LIKE '%enq%'
ORDER BY B.LOGON_TIME
/


--- CHECAR HISTORY LOCK PASSADO 2
COL EVENT FOR A40
COL SQL_ADDRESS FOR A20
COL USERNAME FOR A20
SELECT DISTINCT(A.SESSION_ID), A.SESSION_SERIAL#, B.USERNAME, A.SQL_ID, B.SQL_ADDRESS, B.LOGON_TIME, A.EVENT
FROM V$ACTIVE_SESSION_HISTORY A, V$SESSION B
WHERE A.SESSION_ID = B.SID
AND A.SESSION_SERIAL# = B.SERIAL#
AND A.EVENT LIKE '%enq%'
ORDER BY B.LOGON_TIME
/


--- CRIAR REDOLOG PARA DATAGUARD
SELECT 'ALTER DATABASE ADD '||REPLACE(TYPE,'ONLINE','')||' LOGFILE GROUP '||' '||GROUP#|| ' '||''''||REPLACE(MEMBER, '+DG_RAC_REDO_01/rac','+DG_STDB_REDO_01/STDB')||''''||''||' SIZE 500M;'
FROM V$LOGFILE
ORDER BY 1
/

--- CHECAR COLETA DE ESTATÍSTICAS DE TABELAS
SELECT OWNER, TABLE_NAME, TABLESPACE_NAME, STATUS, DEGREE, LAST_ANALYZED
FROM DBA_TABLES
WHERE LAST_ANALYZED < (SELECT SYSDATE FROM DUAL)
ORDER BY LAST_ANALYZED
/


--- COLETAR ESTATÍSTICA SISTEMA (SYSTEM STATISTICS)
Begin

        DBMS_STATS.GATHER_SYSTEM_STATS('INTERVAL', INTERVAL=>720);
        DBMS_STATS.GATHER_DICTIONARY_STATS(OPTIONS =>'GATHER',degree => DBMS_STATS.AUTO_DEGREE, ESTIMATE_PERCENT=>DBMS_STATS.AUTO_SAMPLE_SIZE);
        DBMS_STATS.GATHER_FIXED_OBJECTS_STATS;

end;
/


--- COLETAR ESTATÍSTICA SCHEMA
EXEC DBMS_STATS.GATHER_SCHEMA_STATS( -
OWNNAME => '&SCHEMA', -
ESTIMATE_PERCENT => DBMS_STATS.AUTO_SAMPLE_SIZE, -
CASCADE => TRUE, -
METHOD_OPT => 'FOR ALL COLUMNS SIZE AUTO' );
/


--- COLETAR ESTATÍSTICA TABLE & INDEX
exec DBMS_STATS.GATHER_TABLE_STATS (ownname => '&owner' , tabname => '&table',cascade => true, estimate_percent => 30,method_opt=>'for all indexed columns size 1', granularity => 'ALL', degree => 10);
exec DBMS_STATS.GATHER_INDEX_STATS (ownname => '&owner' , indname => '&index',estimate_percent => 30,granularity => 'ALL', degree => 10);
exec DBMS_STATS.GATHER_INDEX_STATS (ownname => '&owner', indname => '&index', estimate_percent => dbms_stats.auto_sample_size);


--- DESBLOQUEAR COLETA DE STATÍSTICA DAS TABELAS
SELECT 'EXEC DBMS_STATS.UNLOCK_TABLE_STATS('''||OWNER||''','''||TABLE_NAME||''');' FROM DBA_TAB_STATISTICS WHERE STATTYPE_LOCKED IS NOT NULL AND OWNER NOT IN ('SYS','SYSTEM');


---# EXEMPLO ALTERAR METRICAS E THRESHOLD NA DBMS_SERVER_ALERT
BEGIN
DBMS_SERVER_ALERT.SET_THRESHOLD(
METRICS_ID => DBMS_SERVER_ALERT.LOGONS_SEC,
WARNING_OPERATOR => DBMS_SERVER_ALERT.OPERATOR_GE,
WARNING_VALUE => '150',
CRITICAL_OPERATOR => DBMS_SERVER_ALERT.OPERATOR_GE,
CRITICAL_VALUE => '200',
OBSERVATION_PERIOD => 1,
CONSECUTIVE_OCCURRENCES => 2,
INSTANCE_NAME => 'sisag1',
OBJECT_TYPE => DBMS_SERVER_ALERT.OBJECT_TYPE_SYSTEM ,
OBJECT_NAME => ''
);
END;
/


--- CAPTURAR VARIÁVEIS BIND
COL VALUE_STRING FOR A30
SELECT SQL_ID, HASH_VALUE, ADDRESS, NAME, POSITION, WAS_CAPTURED, LAST_CAPTURED, VALUE_STRING
FROM V$SQL_BIND_CAPTURE
WHERE SQL_ID = '&SQL_ID'
AND WAS_CAPTURED = 'YES'
/


--- VERIFICAR SE TABELA TÊM ÍNDICE
COL COLUMN_NAME FOR A20
SELECT OWNER, INDEX_NAME, INDEX_TYPE, TABLE_OWNER, TABLE_NAME, TABLESPACE_NAME, STATUS
FROM DBA_INDEXES
WHERE OWNER = '&OWNER'
AND TABLE_NAME = '&TABLE_NAME'
/



--- VERIFICAR CAMPO DO ÍNDICE
COL COLUMN_NAME FOR A40
SELECT INDEX_OWNER, INDEX_NAME, TABLE_OWNER, TABLE_NAME, COLUMN_NAME, COLUMN_POSITION
FROM DBA_IND_COLUMNS
WHERE INDEX_OWNER = '&OWNER'
AND TABLE_NAME = '&TABLE_NAME'
AND INDEX_NAME = '&INDEX_NAME'
/



---# VERIFICAR SE COLUNA TÊM ÍNDICE:
SELECT INDEX_OWNER, INDEX_NAME, TABLE_OWNER, TABLE_NAME, COLUMN_NAME, COLUMN_POSITION
FROM DBA_IND_COLUMNS
WHERE INDEX_OWNER = '&OWNER'
AND COLUMN_NAME = '&COLUMN'
/



--- VERIFICAR FK's DE UMA CONSTRAINT (PK)
SELECT * FROM DBA_CONSTRAINTS
WHERE R_CONSTRAINT_NAME IN
(SELECT CONSTRAINT_NAME FROM DBA_CONSTRAINTS WHERE CONSTRAINT_NAME = '&PK_NAME')
/

--- VERIFICAR FK QUE NÃO TÊM ÍNDICE
COL COLUMN_NAME FOR A30
COL TABLE_NAME FOR A30
SELECT * FROM (
SELECT C.TABLE_NAME, CC.COLUMN_NAME, CC.POSITION COLUMN_POSITION
FROM   DBA_CONSTRAINTS C, DBA_CONS_COLUMNS CC
WHERE  C.CONSTRAINT_NAME = CC.CONSTRAINT_NAME
AND    C.CONSTRAINT_TYPE = 'R'
AND C.OWNER='&OWNER'
MINUS
SELECT I.TABLE_NAME, IC.COLUMN_NAME, IC.COLUMN_POSITION
FROM   DBA_INDEXES I, DBA_IND_COLUMNS IC
WHERE  I.INDEX_NAME = IC.INDEX_NAME
AND I.OWNER='&OWNER'
)
ORDER BY TABLE_NAME, COLUMN_POSITION
/


--- VERIFICAR SEQUENCES DE UMA TABLE ESPECÍFICA:
SELECT S.SEQUENCE_OWNER, S.SEQUENCE_NAME, T.TABLE_NAME, T.TABLESPACE_NAME 
FROM DBA_SEQUENCES S, DBA_TABLES T
WHERE S.SEQUENCE_OWNER = T.OWNER     
AND T.TABLE_NAME = '&TABLE'
/


--- VERIFICAR SEGMENTO QUE NÃO PODE CRESCER DEVIDO FALTA DE ESPAÇO NA TABLESPACE
SELECT S.OWNER, S.SEGMENT_NAME, S.SEGMENT_TYPE,
S.TABLESPACE_NAME, S.NEXT_EXTENT
FROM DBA_SEGMENTS S
WHERE S.NEXT_EXTENT > (SELECT MAX(F.BYTES)
FROM DBA_FREE_SPACE F
WHERE F.TABLESPACE_NAME = S.TABLESPACE_NAME)
/


--- VERIFICAR SINCRONISMO ENTRE PRIMARY E STANDBY DATABASE
SELECT ARCH.THREAD# "Thread", ARCH.SEQUENCE# "Last Sequence Received", APPL .SEQUENCE# "Last Sequence Applied", (ARCH.SEQUENCE#-APPL.SEQUENCE#) "Difference"
FROM (SELECT THREAD# ,SEQUENCE# FROM V$ARCHIVED_LOG WHERE (THREAD#,FIRST_TIME  ) IN (SELECT THREAD#,MAX(FIRST_TIME) FROM V$ARCHIVED_LOG GROUP BY THREAD#)) ARCH,
(SELECT THREAD# ,SEQUENCE# FROM V$LOG_HISTORY WHERE (THREAD#,FIRST_TIME ) IN (SELECT THREAD#,MAX(FIRST_TIME) FROM V$LOG_HISTORY GROUP BY THREAD#)) APPL WHERE 
ARCH.THREAD# = APPL.THREAD# ORDER BY 1
/

--- VERIFICAR SINCRONISMO ENTRE PRIMARY DATABASE E STANDBY DATABASE
SELECT TO_CHAR(MAX(SEQUENCE#)), TO_CHAR(MAX(FIRST_CHANGE#)), TO_CHAR(MAX(NEXT_CHANGE#))
FROM V$ARCHIVED_LOG
GROUP BY 1,2,3
/

--- VERIFICAR POR QUAL NÓ FOI INICIADO O PROCESSO DE APLICAÇÃO DE ARCHIVE NO STANDBY
SELECT INST_ID, PROCESS, STATUS FROM GV$MANAGED_STANDBY WHERE UPPER(PROCESS) LIKE 'MRP%'
/


--- LISTAR USUÁRIOS USANDO TABLESPACE TEMP
SELECT SE.USERNAME USERNAME, SE.SID SID, SE.SERIAL# SERIAL#, SE.STATUS STATUS, SE.SQL_HASH_VALUE, SE.PREV_HASH_VALUE,SE.MACHINE MACHINE,
SU.TABLESPACE TABLESPACE,SU.SEGTYPE, SU.CONTENTS CONTENTS
FROM V$SESSION SE, V$SORT_USAGE SU WHERE SE.SADDR=SU.SESSION_ADDR
/


--- FAZER TRACE DA SESSÃO COM DBMS_MONITOR
EXECUTE DBMS_MONITOR.SESSION_TRACE_ENABLE (session_id => &sid, serial_num => &serial, waits => TRUE, binds => TRUE);

--- FINALIZAR TRACE DA SESSÃO TRACE DBMS_MONITOR
EXECUTE DBMS_MONITOR.SESSION_TRACE_DISABLE (session_id => &sid, serial_num => &serial);

--- FAZER TRACE DA SESSÃO COM DBMS_SYSTEM
EXEC DBMS_SYSTEM.SET_EV(&sid, &serial, 10046, 12, '');
EXEC SYS.DBMS_SYSTEM.SET_SQL_TRACE_IN_SESSION(&sid,&serial,TRUE);

--- FINALIZAR TRACE DA SESSÃO
EXEC SYS.DBMS_SYSTEM.SET_SQL_TRACE_IN_SESSION(&sid,&serial,FALSE);


--- FAZER TRACE DA SESSÃO COM NOME DO TRACE PERSONALIZADO
ALTER SESSION SET TRACEFILE_IDENTIFIER = "MEU_ARQUIVO_DE_TRACE";
ALTER SESSION SET EVENTS '10046 trace name context forever, level 12';



--- EXECUTAR TKPROF EM TRACE
tkprof qa11_ora_15106.trc qa11_ora_15106.trc.prf sys=no waits=yes sort=prscnt,execnt,exeela
tkprof fod1_ora_4129234.trc fod1_ora_4129234.prf explain=indralog/vivo2010 table=sys.plan_table$ sort=prsela,fchela,exeela print=20;





--- FINALIZAR TRACE DA SESSÃO
EXECUTE DBMS_MONITOR.SESSION_TRACE_DISABLE(session_id => &sid, serial_num => &serial);


--- LISTAR SESSÃO COM TRACE
SELECT A.INST_ID, A.OSUSER,A.SID,A.SERIAL#,A.SCHEMANAME,A.STATUS,A.PROGRAM, TO_CHAR(A.LOGON_TIME,'DDMMYY-HH24:MI:SS') LOGON,
B.SPID, A.SQL_ID, A.SQL_TRACE, A.SQL_TRACE_BINDS, A.SQL_TRACE_WAITS, B.TRACEID, B.TRACEFILE 
FROM GV$SESSION A,GV$PROCESS B
WHERE A.INST_ID = B.INST_ID
AND A.PADDR=B.ADDR
AND A.SID = &SID AND A.SERIAL# = &SERIAL
/



---# DROPAR MATERIALIZED VIEW DE TABLESPACE ESPECÍFICA
SELECT 'DROP MATERIALIZED VIEW '||OWNER||'.'||NAME||' PRESERVE TABLE;'
FROM DBA_REGISTERED_SNAPSHOTS
WHERE NAME IN (SELECT TABLE_NAME FROM DBA_TABLES WHERE TABLESPACE_NAME = '&TABLESPACE_NAME')
/




--- VERIFICAR A QUANTIDADE DE EVENTOS:
COL EVENT FOR A60
SELECT EVENT, COUNT(SID)
FROM V$SESSION
GROUP BY EVENT
ORDER BY EVENT
/

--- VERIFICAR VALOR PARAMETRO: _CKPT_RETENTION_CHECK_FREQ
COL NAME FOR A40
COL VALUE FOR A40
SELECT DECODE(PROCESS_TYPE,1,'APPLY',2,'CAPTURE') PROCESS_NAME,
NAME, VALUE
FROM SYS.STREAMS$_PROCESS_PARAMS
WHERE NAME = '_CKPT_RETENTION_CHECK_FREQ'
ORDER BY 1,2
/



---# VERIFICAR SE O BANCO STANDBY ESTÁ COM REAL TIME APPLY HABILITADO
COL DEST_NAME FOR A30
SELECT INST_ID, DEST_ID,DEST_NAME,STATUS,TYPE,SRL,RECOVERY_MODE FROM GV$ARCHIVE_DEST_STATUS
/


--- FORÇAR CHECKPOINT (MIN_REQUIRED_CAPTURE_CHANGE# - V$DATABASE)
DBMS_CAPTURE_ADM.SET_PARAMETER(CAPTURE_NAME, '_CHECKPOINT_FORCE',. 'Y');


--- CHECAR QUAL SEQUENCE# É REQUERIDA PARA PODER DELETAR ARCHIVE GOLDENGATE: RMAN-08137: WARNING: archived log not deleted, needed for standby or upstream capture process
SELECT THREAD#,DEST_ID,SEQUENCE#,FIRST_TIME,FIRST_CHANGE#,NEXT_TIME,NEXT_CHANGE#
FROM V$ARCHIVED_LOG
WHERE FIRST_CHANGE# <= (SELECT MIN_REQUIRED_CAPTURE_CHANGE# FROM V$DATABASE)
AND NEXT_CHANGE# >= (SELECT MIN_REQUIRED_CAPTURE_CHANGE# FROM V$DATABASE)
/


--- VERIFICAR LOCK
COL OBJECT_NAME FOR A30
COL OBJECT_TYPE FOR A10
COL ORACLE_USERNAME FOR A10
COL MODE_HELD FOR A15
COL BLOCKING_OTHERS FOR A20
SELECT /*+ RULE */ DISTINCT(S.SQL_ADDRESS), S.SQL_ID, D.SESSION_ID, D.MODE_HELD, D.BLOCKING_OTHERS, C.SQL_ID AS SQL_LOCADOR, C.ADDRESS AS ADDRESS_LOCADOR, K.BLOCK, O.OBJECT_NAME, O.OBJECT_TYPE, L.ORACLE_USERNAME, L.LOCKED_MODE
FROM DBA_LOCKS D, V$LOCKED_OBJECT L, DBA_OBJECTS O, V$LOCK K, V$SESSION S, V$OPEN_CURSOR C
WHERE D.SESSION_ID = L.SESSION_ID
AND D.LOCK_ID1 = K.ID1
AND D.LOCK_ID2 = K.ID2
AND K.BLOCK = 0
AND D.SESSION_ID = S.SID
AND O.OBJECT_ID = L.OBJECT_ID
AND S.SID = C.SID
GROUP BY S.SQL_ADDRESS, S.SQL_ID, D.SESSION_ID, D.MODE_HELD, D.BLOCKING_OTHERS, C.SQL_ID, C.ADDRESS, K.BLOCK, O.OBJECT_NAME, O.OBJECT_TYPE, L.ORACLE_USERNAME, L.LOCKED_MODE
ORDER BY 3
/


--- VERIFICAR CONSTRAINTS DE UMA TABELA ESPECÍFICA
COL COLUMN_NAME FOR A30
COL OWNER FOR A10
SELECT P.OWNER, P.CONSTRAINT_NAME, P.CONSTRAINT_TYPE, P.TABLE_NAME, P.R_OWNER, P.R_CONSTRAINT_NAME AS FOREIGN_KEY, P.STATUS,
C.COLUMN_NAME, C.POSITION
FROM DBA_CONSTRAINTS P, DBA_CONS_COLUMNS C
WHERE P.CONSTRAINT_NAME = C.CONSTRAINT_NAME
AND P.OWNER = '&OWNER'
AND P.TABLE_NAME = '&TABLE'
ORDER BY 4, 9
/


--- VERIFICAR FOREIGN KEYS REFERENTE UMA PRIMARY KEY ESPECÍFICA
COL OWNER FOR A10
COL R_OWNER FOR A10
COL R_CONSTRAINT_NAME FOR A10
COL COLUMN_NAME FOR A30
SELECT P.OWNER, P.CONSTRAINT_NAME, P.CONSTRAINT_TYPE, P.TABLE_NAME, P.R_OWNER, P.R_CONSTRAINT_NAME AS FOREIGN_KEY, P.STATUS,
C.COLUMN_NAME, C.POSITION
FROM DBA_CONSTRAINTS P, DBA_CONS_COLUMNS C
WHERE P.CONSTRAINT_NAME = C.CONSTRAINT_NAME
AND P.OWNER = '&OWNER'
AND P.CONSTRAINT_TYPE = 'R'
AND P.R_CONSTRAINT_NAME = '&PK'
ORDER BY 4, 9
/



--- VERIFICAR TIMEZONE DO BANCO DE DADOS
SELECT DBTIMEZONE,SESSIONTIMEZONE FROM DUAL
/




--- VERIFICAR CRESCIMENTO DIARIO TABLESPACE_NAME
SELECT TO_CHAR (SP.BEGIN_INTERVAL_TIME,'DD-MM-YYYY') DAYS
, TS.TSNAME
, MAX(ROUND((TSU.TABLESPACE_SIZE* DT.BLOCK_SIZE )/(1024*1024),2) ) CUR_SIZE_MB
, MAX(ROUND((TSU.TABLESPACE_USEDSIZE* DT.BLOCK_SIZE )/(1024*1024),2)) USEDSIZE_MB
FROM DBA_HIST_TBSPC_SPACE_USAGE TSU
, DBA_HIST_TABLESPACE_STAT TS
, DBA_HIST_SNAPSHOT SP
, DBA_TABLESPACES DT
WHERE TSU.TABLESPACE_ID= TS.TS#
AND TSU.SNAP_ID = SP.SNAP_ID
AND TS.TSNAME = DT.TABLESPACE_NAME
AND TS.TSNAME NOT IN ('SYSAUX','SYSTEM')
AND TS.TSNAME = '&TABLESPACE_NAME'
AND TO_CHAR (SP.BEGIN_INTERVAL_TIME,'DD-MM-YYYY') BETWEEN '&DATE1' AND '&DATE2'
GROUP BY TO_CHAR (SP.BEGIN_INTERVAL_TIME,'DD-MM-YYYY'), TS.TSNAME
ORDER BY TO_CHAR (SP.BEGIN_INTERVAL_TIME,'DD-MM-YYYY')
/



--- VERIFICAR QUANTIDADE DE SWITCH POR HORA DO REDOLOG
SET LINES 200
SET PAGES 2000
SELECT
TO_CHAR(FIRST_TIME,'DD-MM-YYYY') DAY,
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'00',1,0)),'99') "00",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'01',1,0)),'99') "01",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'02',1,0)),'99') "02",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'03',1,0)),'99') "03",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'04',1,0)),'99') "04",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'05',1,0)),'99') "05",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'06',1,0)),'99') "06",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'07',1,0)),'99') "07",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'08',1,0)),'99') "0",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'09',1,0)),'99') "09",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'10',1,0)),'99') "10",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'11',1,0)),'99') "11",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'12',1,0)),'99') "12",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'13',1,0)),'99') "13",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'14',1,0)),'99') "14",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'15',1,0)),'99') "15",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'16',1,0)),'99') "16",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'17',1,0)),'99') "17",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'18',1,0)),'99') "18",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'19',1,0)),'99') "19",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'20',1,0)),'99') "20",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'21',1,0)),'99') "21",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'22',1,0)),'99') "22",
TO_CHAR(SUM(DECODE(TO_CHAR(FIRST_TIME,'HH24'),'23',1,0)),'99') "23"
FROM V$LOG_HISTORY
GROUP BY TO_CHAR(FIRST_TIME,'DD-MM-YYYY')
ORDER BY TO_CHAR(FIRST_TIME,'DD-MM-YYYY')
/


--- VERIFICAR A QUANTIDADE DE SWITCH DIÁRIOS DO REDOLOG
COL C1 FORMAT A10 HEADING "MONTH"
COL C2 FORMAT A40 HEADING "ARCHIVE DATE"
COL C3 FORMAT 999 HEADING "SWITCHES"
COMPUTE AVG OF C ON A
COMPUTE AVG OF C ON REPORT
BREAK ON A SKIP 1 ON REPORT SKIP 1
SELECT TO_CHAR(TRUNC(FIRST_TIME), 'MONTH') C1, TO_CHAR(TRUNC(FIRST_TIME), 'DAY : DD-MM-YYYY') C2, COUNT(*) C3
FROM V$LOG_HISTORY
WHERE TRUNC(FIRST_TIME) > LAST_DAY(SYSDATE-100) +1
GROUP BY TRUNC(FIRST_TIME)
ORDER BY TO_CHAR(TRUNC(FIRST_TIME))
/


--- VERIFICAR VOLUME DE REDOS DIARIAMENTE
SELECT A.*, ROUND(A.COUNT#*B.AVG#/1024/1024/1024) DAILY_AVG_GB
FROM
(SELECT TO_CHAR(FIRST_TIME,'DD-MM-YYYY') DAY, COUNT(1) COUNT#, MIN(RECID) MIN#,MAX(RECID) MAX#
FROM V$LOG_HISTORY
GROUP BY TO_CHAR(FIRST_TIME,'DD-MM-YYYY')
ORDER BY 1
) A,
(SELECT AVG(BYTES) AVG#, COUNT(1) COUNT#, MAX(BYTES) MAX_BYTES, MIN(BYTES) MIN_BYTES
FROM V$LOG) B
/



--- AUDIT TRAIL
COL USERNAME FOR A20
COL OS_USERNAME FOR A20
COL USERHOST FOR A25
COL TERMINAL FOR A15
COL OWNER FOR A12
COL OBJ_NAME FOR A30
COL ACTION_NAME FOR A20
COL SQL_TEXT FOR A30
COL STATUS FOR A10
SELECT AT.USERNAME, AT.OS_USERNAME, AT.USERHOST, AT.OWNER, AT.OBJ_NAME, AT.ACTION_NAME, AT.OS_PROCESS, O.LAST_DDL_TIME, O.SELECT OWNER, TASK_NAME, STATUS FROM DBA_ADVISOR_TASKS
FROM DBA_AUDIT_TRAIL AT, V$PROCESS PR, DBA_OBJECTS O
WHERE AT.OWNER = '&OWNER'
AND AT.OS_PROCESS = PR.SPID
AND AT.OBJ_NAME = O.OBJECT_NAME
ORDER BY O.LAST_DDL_TIME
/

--- CRIAR INSTRUCAO SET NEWNAME DATAFILES (RMAN)
SELECT 'SET NEWNAME FOR DATAFILE ' || FILE# || ' TO ''' || REPLACE(NAME,'CDB12C','CDBSTDB') || ''';'
FROM V$DATAFILE
/

--- CRIAR INSTRUCAO SET NEWNAME TEMPFILES (RMAN)
SELECT 'SET NEWNAME FOR TEMPFILE ' || FILE# || ' TO ''' || REPLACE(NAME,'CDB12C','CDBSTDB') || ''';'
FROM V$TEMPFILE
/

--- CRIAR INSTRUCAO RENAME FILE PARA REDOLOG (RMAN)
SELECT 'SQL "ALTER DATABASE RENAME FILE ''''' || MEMBER || '''''' || ' TO ' || '''''' || REPLACE(MEMBER, 'CDB12C','CDBSTDB') || ''''' ";'
FROM V$LOGFILE
/


--- VERIFICAR LAST CHANGE OBJECT_NAME
SET LINESIZE 1000
SET PAGESIZE 10000
COLUMN D_NAME FORMAT A20
COLUMN P_NAME FORMAT A20
SELECT
DO.OBJ# D_OBJ,
DO.NAME D_NAME,
DO.TYPE# D_TYPE,
PO.OBJ# P_OBJ,
PO.NAME P_NAME,
TO_CHAR(P_TIMESTAMP,'DD-MON-YYYY HH24:MI:SS') "P_TIMESTAMP",
TO_CHAR(PO.STIME ,'DD-MON-YYYY HH24:MI:SS') "STIME",
DECODE(SIGN(PO.STIME-P_TIMESTAMP),0,'SAME','*DIFFER*') X
FROM SYS.OBJ$ DO, SYS.DEPENDENCY$ D, SYS.OBJ$ PO
WHERE P_OBJ#=PO.OBJ#(+)
AND D_OBJ#=DO.OBJ#
AND DO.STATUS=1 /*DEPENDENT IS VALID*/
AND PO.STATUS=1 /*PARENT IS VALID*/
AND PO.STIME!=P_TIMESTAMP /*PARENT TIMESTA 8 9 10 11 12 13 14 15 MP NOT MATCH*/
ORDER BY 2,1
/




--- EXECUTAR ADVISOR FRAGMENTED TABLE
VARIABLE ID NUMBER;
BEGIN
  DECLARE
  NAME VARCHAR2(100);
  DESCR VARCHAR2(500);
  OBJ_ID NUMBER;
  BEGIN
  NAME:='Fragmented Table';
  DESCR:='Segment Advisor Fragmented Table';

  DBMS_ADVISOR.CREATE_TASK (
    ADVISOR_NAME     => 'Segment Advisor',
    TASK_ID          => :ID,
    TASK_NAME        => NAME,
    TASK_DESC        => DESCR);

  DBMS_ADVISOR.CREATE_OBJECT (
    TASK_NAME        => NAME,
    OBJECT_TYPE      => 'TABLE',
    ATTR1            => '&OWNER',
    ATTR2            => '&TABLE_NAME',
    ATTR3            => NULL,
    ATTR4            => NULL,
    ATTR5            => NULL,
    OBJECT_ID        => OBJ_ID);

  DBMS_ADVISOR.SET_TASK_PARAMETER(
    TASK_NAME        => NAME,
    PARAMETER        => 'RECOMMEND_ALL',
    VALUE            => 'TRUE');

  DBMS_ADVISOR.EXECUTE_TASK(NAME);
  END;
END;
/



--- VERIFICAR STATUS DA TASK FRAGMENTED TABLE
SELECT OWNER, TASK_NAME, STATUS FROM DBA_ADVISOR_TASKS
WHERE TASK_NAME = 'Fragmented Table';


---VERIFICAR O ADVISOR PARA A TABELA SOBRE A TASK FRAGMENTED TABLE
COL MESSAGE FOR A80
COL SEGNAME FOR A20
COL PARTITION FOR A20
COL TYPE FOR A20
SELECT AF.TASK_NAME, AO.ATTR2 SEGNAME, /*AO.ATTR3 PARTITION, AO.TYPE,*/ AF.MESSAGE
FROM DBA_ADVISOR_FINDINGS AF, DBA_ADVISOR_OBJECTS AO
WHERE AO.TASK_ID = AF.TASK_ID
AND AO.OBJECT_ID = AF.OBJECT_ID
AND AF.TASK_NAME = 'Fragmented Table'
/


--- DROPAR ADVISOR FRAGMENTED TABLE
EXEC DBMS_ADVISOR.DELETE_TASK('Fragmented Table');


--- LISTAR SESSAO USANDO OBJETO
SELECT A.*, B.USERNAME, B.MACHINE, B.LOGON_TIME, B.STATUS
FROM V$ACCESS A
INNER JOIN V$SESSION B ON A.SID=B.SID
WHERE A.TYPE='TABLE'
AND A.OWNER = '&OWNER'
AND A.OBJECT='&TABLE'
/

--- FLASHBACK QUERY
SELECT * FROM KDBOPER.AGREEMENTS 
AS OF TIMESTAMP
TO_TIMESTAMP('2017-05-10 07:00:00', 'YYYY-MM-DD HH:MI:SS')
WHERE NAME = 'ALLFUNDS STATIC'
UNION ALL
SELECT * FROM KDBOPER.AGREEMENTS 
WHERE NAME = 'ALLFUNDS STATIC'
/

--- FLASHBACK QUERY
SELECT * FROM KDBREF.CALENDARS 
AS OF TIMESTAMP
TO_TIMESTAMP('2017-05-10 07:00:00', 'YYYY-MM-DD HH:MI:SS')
WHERE CAL_ID = 12513
UNION ALL 
SELECT * FROM KDBREF.CALENDARS 
WHERE CAL_ID = 12513
/


--- MERGE UPDATE
MERGE INTO KDBREF.CALENDARS C
USING (SELECT CAL_ID, CODE FROM KDBREF.LEO_TESTE ORDER BY CAL_ID) L 
ON (C.CAL_ID = L.CAL_ID)
WHEN MATCHED THEN UPDATE SET C.CODE = L.CODE
/



--- GERAR SCRIPT GRANT PARA ROLE DE MANUTENCAO NOS OBJETOS QUE NÃO ESTÃO NA ROLE
SELECT 'GRANT '||DECODE(OBJECT_TYPE, 'TABLE', 'INSERT, SELECT, UPDATE, DELETE ', 'PROCEDURE', 'EXECUTE', 'FUNCTION', 'EXECUTE', 'PACKAGE', 'EXECUTE', 'SEQUENCE', 'SELECT', 'VIEW', 'SELECT')||' ON '||OWNER||'."'||OBJECT_NAME||'" TO &ROLE_NAME' CMD
FROM DBA_OBJECTS O
WHERE OWNER ='&OWNER'
AND OBJECT_TYPE IN ('TABLE', 'PROCEDURE', 'FUNCTION', 'VIEW', 'SEQUENCE', 'PACKAGE')
--AND OBJECT_NAME NOT LIKE 'SYS_IOT_%'
AND NOT EXISTS (
SELECT 1
FROM DBA_TAB_PRIVS
WHERE TABLE_NAME = OBJECT_NAME AND OWNER=O.OWNER
AND GRANTEE ='&ROLE_NAME'
)
/



--- EXECUTAR SCRIPT GRANT PARA ROLE DE MANUTENCAO NOS OBJETOS QUE NÃO ESTÃO NA ROLE
DECLARE
  SQL_TEXT VARCHAR2(500);
BEGIN
  FOR REG IN (
    SELECT 'GRANT '||DECODE(OBJECT_TYPE, 'TABLE', 'INSERT, SELECT, UPDATE, DELETE ', 'PROCEDURE', 'EXECUTE', 'FUNCTION', 'EXECUTE', 'PACKAGE', 'EXECUTE', 'SEQUENCE', 'SELECT', 'VIEW', 'SELECT')||' ON '||OWNER||'."'||OBJECT_NAME||'" TO &ROLE_NAME' CMD
    FROM DBA_OBJECTS O
    WHERE OWNER ='&OWNER'
    AND OBJECT_TYPE IN ('TABLE', 'PROCEDURE', 'FUNCTION', 'VIEW', 'SEQUENCE', 'PACKAGE')
    --AND OBJECT_NAME NOT LIKE 'SYS_IOT_%'
    AND NOT EXISTS (
    SELECT 1
    FROM DBA_TAB_PRIVS
    WHERE TABLE_NAME = OBJECT_NAME AND OWNER=O.OWNER
    AND GRANTEE ='&ROLE_NAME'
)
  ) LOOP
    BEGIN
      SQL_TEXT := REG.CMD;
      DBMS_OUTPUT.PUT_LINE(SQL_TEXT);
      EXECUTE IMMEDIATE SQL_TEXT;
    END;
  END LOOP;
END;
/



--- GERAR SCRIPT GRANT PARA ROLE DE CONSULTA NOS OBJETOS QUE NÃO ESTÃO NA ROLE
SELECT 'GRANT '||DECODE(OBJECT_TYPE, 'TABLE', 'SELECT', 'PROCEDURE', 'EXECUTE', 'FUNCTION', 'EXECUTE', 'PACKAGE', 'EXECUTE', 'SEQUENCE', 'SELECT', 'VIEW', 'SELECT')||' ON '||OWNER||'."'||OBJECT_NAME||'" TO &ROLE_NAME' CMD
FROM DBA_OBJECTS O
WHERE OWNER ='&OWNER'
AND OBJECT_TYPE IN ('TABLE', 'PROCEDURE', 'FUNCTION', 'VIEW', 'SEQUENCE', 'PACKAGE')
--AND OBJECT_NAME NOT LIKE 'SYS_IOT_%'
AND NOT EXISTS (
SELECT 1
FROM DBA_TAB_PRIVS
WHERE TABLE_NAME = OBJECT_NAME AND OWNER=O.OWNER
AND GRANTEE ='&ROLE_NAME'
)
/



--- EXECUTAR SCRIPT GRANT PARA ROLE DE CONSULTA NOS OBJETOS QUE NÃO ESTÃO NA ROLE
DECLARE
  SQL_TEXT VARCHAR2(500);
BEGIN
  FOR REG IN (
    SELECT 'GRANT '||DECODE(OBJECT_TYPE, 'TABLE', 'SELECT', 'PROCEDURE', 'EXECUTE', 'FUNCTION', 'EXECUTE', 'PACKAGE', 'EXECUTE', 'SEQUENCE', 'SELECT', 'VIEW', 'SELECT')||' ON '||OWNER||'."'||OBJECT_NAME||'" TO &ROLE_NAME' CMD
    FROM DBA_OBJECTS O
    WHERE OWNER ='&OWNER'
    AND OBJECT_TYPE IN ('TABLE', 'PROCEDURE', 'FUNCTION', 'VIEW', 'SEQUENCE', 'PACKAGE')
    --AND OBJECT_NAME NOT LIKE 'SYS_IOT_%'
    AND NOT EXISTS (
    SELECT 1
    FROM DBA_TAB_PRIVS
    WHERE TABLE_NAME = OBJECT_NAME AND OWNER=O.OWNER
    AND GRANTEE ='&ROLE_NAME'
)
  ) LOOP
    BEGIN
      SQL_TEXT := REG.CMD;
      DBMS_OUTPUT.PUT_LINE(SQL_TEXT);
      EXECUTE IMMEDIATE SQL_TEXT;
    END;
  END LOOP;
END;
/



--- GERAR SCRIPT PARA CRIAR SYNONYM PARA OS OBJETOS QUE NÃO POSSUEM EM DETERMINADO SCHEMA
SELECT 'CREATE OR REPLACE SYNONYM '||'&USERNAME_CRIAR_SYNONYM'||'.'||OBJECT_NAME||' FOR '||OWNER||'.'||OBJECT_NAME||'; ' CMD
FROM DBA_OBJECTS O
WHERE OWNER ='&OWNER'
AND OBJECT_TYPE IN ('TABLE', 'PROCEDURE', 'FUNCTION', 'VIEW', 'SEQUENCE', 'PACKAGE')
AND NOT EXISTS (
SELECT 1
FROM DBA_SYNONYMS S
WHERE SYNONYM_NAME = OBJECT_NAME AND S.TABLE_OWNER=O.OWNER
AND S.OWNER ='&USERNAME_CRIAR_SYNONYM'
)
/



--- VERIFICAR SESSÕES QUE NÃO ESTÃO USANDO STRING DE CONEXÃO COM ()LOAD_BALANCE OR FAILOVER)
SELECT USERNAME, SID, SERIAL#,PROCESS,FAILOVER_TYPE,FAILOVER_METHOD FROM GV$SESSION
WHERE UPPER(FAILOVER_METHOD) != 'BASIC' AND UPPER(FAILOVER_TYPE) !='SELECT' AND UPPER(USERNAME) NOT IN ('SYS','SYSTEM','SYSMAN','DBSNMP');



--- EXEMPLO DE GRANT EM QUEUE:
EXECUTE DBMS_AQADM.GRANT_QUEUE_PRIVILEGE (PRIVILEGE =>'DEQUEUE', QUEUE_NAME => 'UMBRELLA.B2W_ESTORNO_CARTAO_AQ', GRANTEE => 'UMBRELLA', GRANT_OPTION => FALSE);   


--- INICIAR UMA QUEUE
EXECUTE DBMS_AQADM.START_QUEUE (QUEUE_NAME => 'UMBRELLA.B2W_ESTORNO_CARTAO_AQ',ENQUEUE=> TRUE,DEQUEUE=> TRUE);


1 - --- PARAR UMA QUEUE
EXECUTE DBMS_AQADM.STOP_QUEUE (QUEUE_NAME => 'B2W_BPEL_AQ.UTM_ENTREGA_LASA_AQ', ENQUEUE=> TRUE,DEQUEUE=> TRUE);

2 - --- DROPAR UMA QUEUE
EXECUTE DBMS_AQADM.DROP_QUEUE (queue_name => 'B2W_BPEL_AQ.UTM_ENTREGA_LASA_AQ'); 

3 - --- DROPAR QUEUE TABLE
EXECUTE DBMS_AQADM.DROP_QUEUE_TABLE (QUEUE_TABLE => 'B2W_BPEL_AQ.UTM_ENTREGA_LASA_TB');


4 - --- DROPAR TYPE
DROP TYPE B2W_BPEL_AQ.UTM_ENTREGA_LASA_TP;


--- CRIAR JOB DE COLETA DE ESTATÍSTICA:


BEGIN
    DBMS_SCHEDULER.CREATE_JOB (
            job_name => '"SYSTEM"."JOB_GATHER_STATS_USU_TKC"',
            schedule_name => '"SYS"."MAINTENANCE_WINDOW_GROUP"',
            job_type => 'PLSQL_BLOCK',
            job_action => 'EXEC DBMS_STATS.GATHER_SCHEMA_STATS( -
OWNNAME => ''USU_TKC'', -
CASCADE => TRUE, -
METHOD_OPT => ''FOR ALL COLUMNS SIZE AUTO'' );',
            number_of_arguments => 0,
            enabled => FALSE,
            auto_drop => FALSE,

            comments => 'Coleta diaria de estatistica schema USU_TKC');


    DBMS_SCHEDULER.SET_ATTRIBUTE(
             name => '"SYSTEM"."JOB_GATHER_STATS_USU_TKC"',
             attribute => 'follow_default_timezone', value => TRUE);     
    DBMS_SCHEDULER.SET_ATTRIBUTE(
             name => '"SYSTEM"."JOB_GATHER_STATS_USU_TKC"',
             attribute => 'parallel_instances', value => TRUE);
    DBMS_SCHEDULER.SET_ATTRIBUTE(
             name => '"SYSTEM"."JOB_GATHER_STATS_USU_TKC"',
             attribute => 'stop_on_window_close', value => TRUE);
    DBMS_SCHEDULER.SET_ATTRIBUTE(
             name => '"SYSTEM"."JOB_GATHER_STATS_USU_TKC"',
             attribute => 'logging_level', value => DBMS_SCHEDULER.LOGGING_OFF);



    DBMS_SCHEDULER.enable(
             name => '"SYSTEM"."JOB_GATHER_STATS_USU_TKC"');
END;


------------------------------------------------------------------------------------------------------------##


--- CRIAR REGRAS ACL DENTRO DO DATABASE
BEGIN
  DBMS_NETWORK_ACL_ADMIN.CREATE_ACL(acl         => 'appbusprd_b2w.xml',
                                    description => 'ACL para para acessar serviço appbusprd',
                                    principal   => 'UMBRELLA',
                                    is_grant    => true,
                                    privilege   => 'connect',
        start_date  => NULL,
                      end_date    => NULL);
END;
/

BEGIN
  DBMS_NETWORK_ACL_ADMIN.ADD_PRIVILEGE(acl       => 'appbusprd_b2w.xml',
                                       principal => 'UMBRELLA_DML',
                                       is_grant  => true,
                                       privilege => 'connect');

END;
/

BEGIN
  DBMS_NETWORK_ACL_ADMIN.ASSIGN_ACL(acl  => 'appbusprd_b2w.xml',
                                    host => '*',
        lower_port => 80,
        upper_port => 80);

END;
/
COMMIT;


--- TESTE CONEXÃO PORTA ACL:
alter session set current_schema = SIEM_CGRANDE;
DECLARE
v_mailsever_host VARCHAR2(30) := 'sender01.sianet.net.br';
v_mailsever_port PLS_INTEGER  := 1521;
l_mail_conn  UTL_SMTP.CONNECTION;
BEGIN
l_mail_conn := UTL_SMTP.OPEN_CONNECTION( v_mailsever_host, v_mailsever_port);
END;
/



--- GERAR TASK DO SQL TUNE ADVISOR

--- ATRAVÉS DA QUERY

DECLARE
MY_TASK_NAME VARCHAR2(30);
MY_SQLTEXT CLOB;
BEGIN
MY_SQLTEXT := 'SELECT COUNT (1) FROM AT_LOG_EMAIL WHERE LOEM_ID_PROTOCOLO = : B2 AND LOEM_ID_TEMPLATE = : B1';
MY_TASK_NAME := DBMS_SQLTUNE.CREATE_TUNING_TASK(
SQL_TEXT => MY_SQLTEXT,
USER_NAME => 'SYS',
SCOPE => 'COMPREHENSIVE',
TIME_LIMIT => 120,
TASK_NAME => 'SQL_TUNE',
DESCRIPTION => 'TASK PARA TUNAR ALGUMAS QUERIES');
END;
/


--- ATRAVÉS DO SQL_ID

DECLARE
MY_TASK_NAME VARCHAR2(30);
BEGIN
MY_TASK_NAME := DBMS_SQLTUNE.CREATE_TUNING_TASK(
SQL_ID => '&sql_id',
SCOPE => 'COMPREHENSIVE',
TIME_LIMIT => 15000,
TASK_NAME => 'SQL_TUNE_QUERY',
DESCRIPTION => 'TASK PARA TUNAR ALGUMAS QUERIES');
END;
/

--- EXECUTAR TASK CRIADA ANTERIORMENTE

EXECUTE DBMS_SQLTUNE.EXECUTE_TUNING_TASK (TASK_NAME => 'SQL_TUNE_QUERY');

--- VERIFICAR STATUS DA EXECUÇÃO DA TASK

SELECT STATUS FROM DBA_ADVISOR_LOG WHERE TASK_NAME='SQL_TUNE_QUERY';

--- EXTRAIR O RELATÓRIO FINAL COM AS RECOMENDAÇÕES

SELECT DBMS_SQLTUNE.REPORT_TUNING_TASK('SQL_TUNE_QUERY') FROM DUAL;

--- DROPAR A TASK ANTERIORMENTE CRIADA

EXECUTE DBMS_SQLTUNE.DROP_TUNING_TASK('SQL_TUNE_QUERY');



--- CRIAR PLAN TABLE (SALVAR ESTATÍSTICAS):
EXECUTE DBMS_STATS.CREATE_STAT_TABLE(OWNNAME=>'SYSTEM', STATTAB=>'BKP_TABLE_STATS');

--- EXECUTA EXPORT DA ESTATÍSTICA:
EXECUTE DBMS_STATS.EXPORT_TABLE_STATS(OWNNAME=>'&TABLE_OWNER', TABNAME=>'&TABLE_NAME', STATOWN=>'SYSTEM', STATTAB=>'BKP_TABLE_STATS', CASCADE=>TRUE);

--- VOLTAR ESTATÍSTICA:
EXEC DBMS_STATS.IMPORT_TABLE_STATS(OWNNAME=>'&TABLE_OWNER', TABNAME=> '&TABLE_NAME',STATTAB=>'BKP_TABLE_STATS');

---VERIFICAR QUANTO TEMPO DE HISTORICO DE ESTATISTICAS TEMOS:
SELECT DBMS_STATS.GET_STATS_HISTORY_AVAILABILITY FROM DUAL;

---VOLTAR AS ESTATISTICAS DE SEXTA FEIRA: 
EXEC SYS.DBMS_STATS.RESTORE_DATABASE_STATS(AS_OF_TIMESTAMP => TO_TIMESTAMP('2015-10-23 03:00:00', 'YYYY-MM-DD HH:MI:SS'));







------------------------##                FILES NOT OPENED                          ---------------------------##

SET PAGESIZE 0
SET LINESIZE 200
COL FULL_ALIAS_PATH FORMAT A80
/*+ ----------------------------------------------------------------
    QUERY WILL RETURN ALL THE FILES STORED ON ASM BUT NOT CURRENLTY
    OPENED BY ANY DATABASE CLIENT OF THE DISKGROUPS
    ORDERED BY GROUP NUMBER, FILE TYPE
    ---------------------------------------------------------------*/

SELECT * FROM (
/*+ -----------------------------------------------------------------
    1ST BRANCH RETURNS ALL THE FILES STORED ON ASM
    -----------------------------------------------------------------*/
SELECT  X.GNUM,X.FILNUM,X.FULL_ALIAS_PATH,F.FTYPE FROM (
SELECT GNUM,FILNUM,CONCAT('+'||GNAME, SYS_CONNECT_BY_PATH(ANAME, '/')) FULL_ALIAS_PATH
FROM (SELECT G.NAME GNAME, A.PARENT_INDEX PINDEX, A.NAME ANAME,
            A.REFERENCE_INDEX RINDEX,A.GROUP_NUMBER GNUM,A.FILE_NUMBER FILNUM
      FROM V$ASM_ALIAS A, V$ASM_DISKGROUP G
      WHERE A.GROUP_NUMBER = G.GROUP_NUMBER)
START WITH (MOD(PINDEX, POWER(2, 24))) = 0 CONNECT BY PRIOR RINDEX = PINDEX) X,
(SELECT GROUP_NUMBER GNUM,FILE_NUMBER FILNUM, TYPE FTYPE FROM V$ASM_FILE ORDER BY GROUP_NUMBER,FILE_NUMBER) F
WHERE X.FILNUM != 4294967295
AND X.GNUM=F.GNUM AND X.FILNUM=F.FILNUM
MINUS
/*+ --------------------------------------------------------------
    2ND BRANCH RETURNS ALL THE FILES STORED ON ASM
    AND CURRENTLY OPENED BY ANY DATABASE CLIENT OF THE DISKGROUPS
    -----------------------------------------------------------------*/
SELECT X.GNUM,X.FILNUM,X.FULL_ALIAS_PATH,F.FTYPE
FROM ( SELECT ID1 GNUM,ID2 FILNUM FROM V$LOCK WHERE TYPE='FA' AND (LMODE=4 OR LMODE=2)) L,
(
SELECT GNUM,FILNUM,CONCAT('+'||GNAME, SYS_CONNECT_BY_PATH(ANAME, '/')) FULL_ALIAS_PATH
FROM (SELECT G.NAME GNAME, A.PARENT_INDEX PINDEX, A.NAME ANAME,
            A.REFERENCE_INDEX RINDEX,A.GROUP_NUMBER GNUM,A.FILE_NUMBER FILNUM
      FROM V$ASM_ALIAS A, V$ASM_DISKGROUP G
      WHERE A.GROUP_NUMBER = G.GROUP_NUMBER)
START WITH (MOD(PINDEX, POWER(2, 24))) = 0 CONNECT BY PRIOR RINDEX = PINDEX
) X,
(SELECT GROUP_NUMBER GNUM,FILE_NUMBER FILNUM, TYPE FTYPE FROM V$ASM_FILE ORDER BY GROUP_NUMBER,FILE_NUMBER) F
WHERE X.FILNUM != 4294967295 AND
X.GNUM=L.GNUM
AND X.FILNUM=L.FILNUM
AND X.GNUM=F.GNUM AND X.FILNUM=F.FILNUM) Q
ORDER  BY Q.GNUM,Q.FTYPE
;


------------------------##                FILES NOT OPENED                          ---------------------------##


--- VERIFICAR JOBS EM EXECUÇÃO
SELECT S.SID, S.SERIAL#, S.USERNAME, S.OSUSER, S.SQL_ID, S.EVENT, S.STATUS, S.LOGON_TIME
FROM DBA_JOBS DJ, DBA_JOBS_RUNNING DJR, V$PROCESS P , V$SESSION S 
WHERE DJ.JOB = DJR.JOB 
AND P.ADDR = S.PADDR 
AND DJR.SID = S.SID
/

EXEC DBMS_SCHEDULER.STOP_JOB('TS.JOB_0000000236_0027199549',FORCE=> TRUE);

------------------------## PARAR JOBS EM EXECUÇÃO, MATAR A SESSÃO E REMOVÊ-LOS ------------------------##


BEGIN
   FOR cursor1 IN (SELECT job
                     FROM dba_jobs
                    WHERE what LIKE '%/* atmp_ctm_nr_sd1582965 */%')
   LOOP
      DBMS_IJOB.broken (cursor1.job, TRUE);
   END LOOP;   

   COMMIT;
END;
/

BEGIN
   FOR cursor1 IN
      (SELECT SID, serial#
         FROM v$session
        WHERE SID IN (
                 SELECT SID
                   FROM dba_jobs_running
                  WHERE job IN (
                              SELECT job
                                FROM dba_jobs
                               WHERE what LIKE
                                              '%/* atmp_ctm_nr_sd1582965 */%')))
   LOOP
      BEGIN
         EXECUTE IMMEDIATE    'alter system kill session '''
                           || TO_CHAR (cursor1.SID)
                           || ''','''
                           || TO_CHAR (cursor1.serial#)
                           || '';
      EXCEPTION
         WHEN OTHERS
         THEN
            DBMS_OUTPUT.put_line ('ERRO ' || SQLERRM);
      END;
   END LOOP;
END;
/
BEGIN
   FOR cursor1 IN (SELECT job
                     FROM dba_jobs
                    WHERE what LIKE '%/* atmp_ctm_nr_sd1582965 */%')
   LOOP
      DBMS_IJOB.remove (cursor1.job);
   END LOOP;   

   COMMIT;
END;
/



--- IDENTIFICADORES PRÉ-DEFINIDOS:
SELECT TYPE_NAME FROM ALL_TYPES WHERE PREDEFINED='YES';


------------------------------------------------------------# JOBS ------------------------------------------------------------#


---# COUNT PARA COMMIT ---#

v_count := v_count + 1;

    if v_count = 10000 then
      commit;
      v_count := 0;
    end if;

------------------------------------------------------------------------------------------------------------------------------##

--- TABELAS CANDIDATAS A REORG:
SET LINES 200;
COLUMN OWNER FORMAT A25;
COLUMN SEGMENT_NAME FORMAT A50;
COLUMN MBS FORMAT A15
COLUMN WASTED FORMAT A15
COLUMN TABLESPACE FORMAT A30
SET PAGES 999
SELECT A.OWNER, A.SEGMENT_NAME, A.SEGMENT_TYPE, A.TABLESPACE_NAME TABLESPACE, TO_CHAR(ROUND(A.BYTES/1024/1024,0)) MBS, TO_CHAR(ROUND((A.BYTES-(B.NUM_ROWS*B.AVG_ROW_LEN) )/1024/1024,0)) WASTED
FROM DBA_SEGMENTS A, DBA_TABLES B
WHERE A.OWNER=B.OWNER
AND A.OWNER NOT LIKE 'SYS%'
AND A.SEGMENT_NAME = B.TABLE_NAME
AND A.SEGMENT_TYPE='TABLE'
GROUP BY A.OWNER, A.SEGMENT_NAME, A.SEGMENT_TYPE, A.TABLESPACE_NAME, ROUND(A.BYTES/1024/1024,0) ,ROUND((A.BYTES-(B.NUM_ROWS*B.AVG_ROW_LEN) )/1024/1024,0)
HAVING ROUND(BYTES/1024/1024,0) >100
ORDER BY ROUND(BYTES/1024/1024,0); 


--- TABELAS MAIS FRAGMENTADAS
COL TABLE_NAME FORMAT A30
COL OWNER FOR A25
SELECT OWNER, TABLE_NAME,ROUND((BLOCKS*8),2) "SIZE (KB)" , 
--SIZE INCLUDING FRAGMENTATION
ROUND((NUM_ROWS*AVG_ROW_LEN/1024/1024),2) "ACTUAL_DATA (MB)",
--NUM_ROWS*AVG_ROW_LEN/1024 = ACTUAL DATA IN TABLE
(ROUND((BLOCKS*8),2) - ROUND((NUM_ROWS*AVG_ROW_LEN/1024/1024),2)) "WASTED_SPACE (MB)"
FROM DBA_TABLES
WHERE (ROUND((BLOCKS*8),2) > ROUND((NUM_ROWS*AVG_ROW_LEN/1024/1024),2))
AND OWNER NOT IN (SELECT USERNAME FROM DBA_USERS WHERE ORACLE_MAINTAINED = 'Y')
ORDER BY 4;

======================TEMP USER USAGE=========================
COL USERNAME FOR A16
COL OSUSER FOR A15
COL PROGRAM FOR A60
COL TABLESPACE FOR A7
SET LINES 300
SET PAGES 999
SELECT   B.TABLESPACE
       , B.SEGFILE#
       , B.SEGBLK#
       , ROUND (  (  ( B.BLOCKS * P.VALUE ) / 1024 / 1024 ), 2 ) SIZE_MB
       , A.SID
       , A.SERIAL#
       , A.USERNAME
       , A.OSUSER
       , A.PROGRAM
       , A.STATUS
    FROM V$SESSION A
       , V$SORT_USAGE B
       , V$PROCESS C
       , V$PARAMETER P
   WHERE P.NAME = 'db_block_size'
     AND A.SADDR = B.SESSION_ADDR
     AND A.PADDR = C.ADDR
     ORDER BY B.TABLESPACE
       , B.SEGFILE#
       , B.SEGBLK#
       , B.BLOCKS;





Adicionar resource do tipo database no grid usando arquivo de parâmetros
crsctl add resource ora.qa3.db -type ora.database.type -file /home/oracle/resqa3


---## MODELO DE EXTERNAL TABLE

 CREATE TABLE "GERAL"."TMP_RELVERBCTORCA"
   (    "CONTA" VARCHAR2(15),
        "DESC1" VARCHAR2(50),
        "TIPO" VARCHAR2(1),
        "FORMATO" VARCHAR2(10),
        "DESTINO" VARCHAR2(30),
        "CATEGORIA" VARCHAR2(20),
        "VERBA" VARCHAR2(12),
        "TCHECK" VARCHAR2(15)
   )
   ORGANIZATION EXTERNAL
    ( TYPE ORACLE_LOADER
      DEFAULT DIRECTORY "EXTERNAL"
      ACCESS PARAMETERS
      ( RECORDS DELIMITED BY NEWLINE
        FIELDS TERMINATED BY ';'
        MISSING FIELD VALUES ARE NULL
          )
      LOCATION
       ( 'RELACIONAMENTO_CONTAS_VS_VERBAS_VS_CARGOS.csv'
       )
    )

------------------------------------------------------------------

--- ADICIONAR UM NOVO NÓ NO RAC:
export IGNORE_PREADDNODE_CHECKS=Y
$GRID_HOME:./addNode.sh CLUSTER_NEW_NODES={amldbsl0sp0005} CLUSTER_NEW_VIRTUAL_HOSTNAMES={amldbsl0sp0005-vip} CLUSTER_NEW_PRIVATE_NODE_NAMES={amldbsl0sp0005-priv}
$ORACLE_HOME:./addNode.sh CLUSTER_NEW_NODES={amldbsl0sp0005} CLUSTER_NEW_VIRTUAL_HOSTNAMES={amldbsl0sp0005-vip} CLUSTER_NEW_PRIVATE_NODE_NAMES={amldbsl0sp0005-priv}

Remover target do OEM 12C:

$OMS_HOME/bin/emcli setup
$OMS_HOME/bin/emcli login -username=SYSMAN
xk96g1ta
$OMS_HOME/bin/emcli delete_target -name="<hostname>:3872" -type="oracle_emd" -delete_monitored_targets -async

dmidecode -t204

lsb_release -id

udev: ENV{DM_NAME}=="asm*", OWNER:="oracle", GROUP:="asmadmin", MODE:="0660"





opatchauto apply /v01s01/12C/Patch_23273629/23273629

opatch apply /v01s01/12C/Patch_23273629/23273629/23054246 -oh /v01s01/app/oracle/product/12.1.0.2.0/dbhome_1


./runcluvfy.sh stage -pre crsinst -n amldbsl0sp0028,amldbsl0sp0029 -r 12.1 -verbose




------------------# AUDITORIA VICTOR ------------------##

verificar o que estás ativo de auditoria:
show parameter audit

set lines 300
set pages 999
select * from dba_priv_audit_opts;

select * from dba_stmt_audit_opts;


ocupantes da sysaux:
select * from  V$SYSAUX_OCCUPANTS order by space_usage_kbytes desc;


Manutenção das "facilities"  de auditoria obtido de:
https://oracle-base.com/articles/11g/auditing-enhancements-11gr2

Com a auditoria ativada a system pode começar a encher e até travar o banco por causa disso. Por tanto seguem a baixo as anotações para resolver esse problema

verificar parametros de config de auditoria (onde está cada tabela, etc)
SELECT * FROM dba_audit_mgmt_config_params;

--tira a aud$ e a fga_log$ da SYSTEM e coloca na SYSAUX
BEGIN
  DBMS_AUDIT_MGMT.init_cleanup(
    audit_trail_type         => DBMS_AUDIT_MGMT.AUDIT_TRAIL_ALL,
    default_cleanup_interval => 12 /* hours */);
END;
/

(desfazer):
BEGIN
  DBMS_AUDIT_MGMT.deinit_cleanup(
    audit_trail_type         => DBMS_AUDIT_MGMT.AUDIT_TRAIL_ALL);
END;
/

--diz qual é o limite (por idade) que queremos manter de logs de auditoria
BEGIN
  DBMS_AUDIT_MGMT.set_last_archive_timestamp(
    audit_trail_type  => DBMS_AUDIT_MGMT.AUDIT_TRAIL_AUD_STD,
    last_archive_time => SYSTIMESTAMP-4);
END;
/

verificar:
SELECT * FROM dba_audit_mgmt_last_arch_ts;

--em caso de use_last_arch_timestamp=TRUE limpa tudo mais antigo que o setado por este parametro. Se FALSE limpa tudo.
BEGIN
  DBMS_AUDIT_MGMT.clean_audit_trail(
   audit_trail_type        => DBMS_AUDIT_MGMT.AUDIT_TRAIL_AUD_STD,
   use_last_arch_timestamp => TRUE);
END;
/


Automatizando...
O codigo a baixo agenda uma limpesa a cada 24h

BEGIN
  DBMS_AUDIT_MGMT.create_purge_job(
    audit_trail_type           => DBMS_AUDIT_MGMT.AUDIT_TRAIL_ALL,
    audit_trail_purge_interval => 24 /* hours */, 
    audit_trail_purge_name     => 'PURGE_ALL_AUDIT_TRAILS',
    use_last_arch_timestamp    => TRUE);
END;
/

É poss[ivel verificar o resultado aqui:
SELECT job_action FROM   dba_scheduler_jobs WHERE  job_name = 'PURGE_ALL_AUDIT_TRAILS';

Habilitar/desabilitar:
BEGIN
  DBMS_AUDIT_MGMT.set_purge_job_status(
    audit_trail_purge_name   => 'PURGE_ALL_AUDIT_TRAILS',
    audit_trail_status_value => DBMS_AUDIT_MGMT.PURGE_JOB_DISABLE);
/

BEGIN
  DBMS_AUDIT_MGMT.set_purge_job_status(
    audit_trail_purge_name   => 'PURGE_ALL_AUDIT_TRAILS',
    audit_trail_status_value => DBMS_AUDIT_MGMT.PURGE_JOB_ENABLE);
END;
/


Alterar o tempo de intervalo:
BEGIN
  DBMS_AUDIT_MGMT.SET_PURGE_JOB_INTERVAL(
    audit_trail_purge_name     => 'PURGE_ALL_AUDIT_TRAILS',
    audit_trail_interval_value => 48);
END;
/

Dropar job:
BEGIN
  DBMS_AUDIT_MGMT.drop_purge_job(
     audit_trail_purge_name     => 'PURGE_ALL_AUDIT_TRAILS');
END;
/

Observação importante:

  1 -  If purge jobs use the last archived timestamp and you do not manually move this timestamp forward, the job will run and have nothing to purge. You should reset the timestamp using DBMS_AUDIT_MGMT.SET_LAST_ARCHIVE_TIMESTAMP when you have made an archive of the audit information, that way your audit information is secure and the job can purge the excess data.
  2 -  The purge job functionality is simply a wrapper over the DBMS_SCHEDULER package to make automating purge jobs easier.

If you want the purge job to maintain an audit trail of a specific number of days, the easiest way to accomplish this is to define a job to set the last archive time automatically. The following job resets the last archive time on a daily basis, keeping the last archive time 30 days in the past.

BEGIN
  DBMS_SCHEDULER.create_job (
    job_name        => 'audit_last_archive_time',
    job_type        => 'PLSQL_BLOCK',
    job_action      => 'BEGIN
                          DBMS_AUDIT_MGMT.SET_LAST_ARCHIVE_TIMESTAMP(DBMS_AUDIT_MGMT.AUDIT_TRAIL_AUD_STD, TRUNC(SYSTIMESTAMP)-30);
                          DBMS_AUDIT_MGMT.SET_LAST_ARCHIVE_TIMESTAMP(DBMS_AUDIT_MGMT.AUDIT_TRAIL_FGA_STD, TRUNC(SYSTIMESTAMP)-30);
                          DBMS_AUDIT_MGMT.SET_LAST_ARCHIVE_TIMESTAMP(DBMS_AUDIT_MGMT.AUDIT_TRAIL_OS, TRUNC(SYSTIMESTAMP)-30,1);
                          DBMS_AUDIT_MGMT.SET_LAST_ARCHIVE_TIMESTAMP(DBMS_AUDIT_MGMT.AUDIT_TRAIL_XML, TRUNC(SYSTIMESTAMP)-30,1);
                        END;',
    start_date      => SYSTIMESTAMP,
    repeat_interval => 'freq=daily; byhour=0; byminute=0; bysecond=0;',
    end_date        => NULL,
    enabled         => TRUE,
    comments        => 'Automatically set audit last archive time.');
END;
/

OBS:
DBMS_AUDIT_MGMT.AUDIT_TRAIL_OS  e DBMS_AUDIT_MGMT.AUDIT_TRAIL_XML necessitam colocar o rac_instance_number senao dá erro como abaixo na execução do job:
ORA-46266: Missing value for argument 'RAC_INSTANCE_NUMBER' in Oracle RAC enabled database
ORA-06512: at "SYS.DBMS_AUDIT_MGMT", line 61
ORA-06512: at "SYS.DBMS_AUDIT_MGMT", line 2259
ORA-06512: at line 4



### LISTENER ESTATICO / STATIC LISTENER
SID_LIST_LISTENER =
  (SID_LIST =
    (SID_DESC =
      (SID_NAME = CDBSTDB)
      (ORACLE_HOME = /opt/oracle/product/12.1.0.2/db)
      (PROGRAM=extproc))
    (SID_DESC =
      (SID_NAME = CDB12C)
      (ORACLE_HOME = /opt/oracle/product/12.1.0.2/db)
      (PROGRAM=extproc)))



##########################################################

[root@stdb12c ~]# df -h
Filesystem                 Size  Used Avail Use% Mounted on
devtmpfs                   852M     0  852M   0% /dev
tmpfs                      6.0G  635M  5.4G  11% /dev/shm
tmpfs                      871M  8.5M  863M   1% /run
tmpfs                      871M     0  871M   0% /sys/fs/cgroup
/dev/sda3                   26G   16G   11G  60% /
/dev/sda1                  283M  167M  116M  59% /boot
/dev/mapper/ol-opt_oracle   19G   13G  6.6G  65% /opt/oracle
tmpfs                      175M     0  175M   0% /run/user/501



[root@stdb12c ~]# xfs_growfs /opt/oracle/
meta-data=/dev/mapper/ol-opt_oracle isize=256    agcount=4, agsize=1220864 blks
         =                       sectsz=512   attr=2, projid32bit=1
         =                       crc=0        finobt=0 spinodes=0
data     =                       bsize=4096   blocks=4883456, imaxpct=25
         =                       sunit=0      swidth=0 blks
naming   =version 2              bsize=4096   ascii-ci=0 ftype=0
log      =internal               bsize=4096   blocks=2560, version=2
         =                       sectsz=512   sunit=0 blks, lazy-count=1
realtime =none                   extsz=4096   blocks=0, rtextents=0
data blocks changed from 4883456 to 7864320
[root@stdb12c ~]# df -h
Filesystem                 Size  Used Avail Use% Mounted on
devtmpfs                   852M     0  852M   0% /dev
tmpfs                      6.0G  635M  5.4G  11% /dev/shm
tmpfs                      871M  8.5M  863M   1% /run
tmpfs                      871M     0  871M   0% /sys/fs/cgroup
/dev/sda3                   26G   16G   11G  60% /
/dev/sda1                  283M  167M  116M  59% /boot
/dev/mapper/ol-opt_oracle   30G   13G   18G  41% /opt/oracle
tmpfs                      175M     0  175M   0% /run/user/501



#### ZERAR / APAGAR / DELETAR SCHEMA ESPECIFICO
declare
vSQL long;
vBaseDrop varchar2(10);
vBaseAtual varchar2(10);
begin
   begin
      select name into vBaseAtual from v$database;
   exception
     when no_data_found then
         dbms_output.put_line('Erro ao encontrar o banco');
   end;
   if '&vBaseDrop' = 'mgteste'  and lower ('&vBaseDrop') = lower (vBaseAtual) then
     begin
      for R_OBJ in (SELECT  FROM ALL_OBJECTS WHERE OWNER = '&SCHEMA' ORDER BY OWNER)
      loop
            vSQL := 'DROP' || ' ' || R_OBJ.OBJECT_TYPE;
            vSQL := vSQL || ' ' || R_OBJ.OWNER;
            vSQL := vSQL || '.' || R_OBJ.OBJECT_NAME;
            if R_OBJ.OBJECT_TYPE = 'TABLE' then
               vSQL := vSQL || ' CASCADE CONSTRAINTS';
            end if;
         begin
            for j in (select object_name from dba_objects where object_name = R_OBJ.OBJECT_NAME) loop
              dbms_output.put_line('Dropando .. '||J.OBJECT_NAME);
            end loop;
            execute immediate vSQL;
            exception
            when OTHERS then NULL;
         end;
      end loop;
     end;
   else
      dbms_output.put_line('Erro ao encontrar o banco, o  atual eh          -> '|| vBaseAtual );
   end if;
 end;
/




####### VILLE DE LUXEMBOURG PROBLEM (EPROSEED)


select sql_handle, ORIGIN, sql_text, plan_name, creator, created, enabled, accepted, fixed
from dba_sql_plan_baselines
where sql_text like '%aud_object_opt%'
/

select sql_handle, ORIGIN, sql_text, plan_name, creator, created, enabled, accepted, fixed
from dba_sql_plan_baselines
where origin = 'MANUAL-LOAD'
/

DECLARE
  l_plans_dropped  PLS_INTEGER;
BEGIN

    FOR REC IN (SELECT DISTINCT SQL_HANDLE FROM DBA_SQL_PLAN_BASELINES WHERE SQL_HANDLE = 'SQL_c96ebf5918a730bd')
    LOOP
   L_PLANS_DROPPED := DBMS_SPM.DROP_SQL_PLAN_BASELINE (
           sql_handle => rec.sql_handle,
          PLAN_NAME  => NULL);
  END LOOP;
  END;
  /

PL/SQL procedure successfully completed.



DECLARE
  l_plans_dropped  PLS_INTEGER;
BEGIN

  FOR REC IN (SELECT DISTINCT SQL_HANDLE FROM DBA_SQL_PLAN_BASELINES)
  LOOP
      L_PLANS_DROPPED := DBMS_SPM.DROP_SQL_PLAN_BASELINE (
        sql_handle => rec.sql_handle,
        PLAN_NAME  => NULL);
  END LOOP;

END;
/


---- BLOCO ANONIMO (REORG TABLE PROC)
SET LINES 200 PAGES 2000
SET ECHO ON
SET SERVEROUTPUT ON

DECLARE

V_OWNER VARCHAR2(60 CHAR) := UPPER('&OWNER');
V_TABLE_NAME VARCHAR2(60 CHAR) := UPPER('&TABLE_NAME');

V_TB_SIZE VARCHAR2(30 CHAR) := NULL;


CURSOR C_REORG_1
IS
SELECT OWNER, TABLE_NAME, TABLESPACE_NAME, PARTITIONED
FROM DBA_TABLES
WHERE OWNER = V_OWNER
AND TABLE_NAME = V_TABLE_NAME;

CURSOR C_REORG_2
IS
SELECT TABLE_OWNER, TABLE_NAME, TABLESPACE_NAME, PARTITION_NAME
FROM DBA_TAB_PARTITIONS
WHERE TABLE_OWNER = V_OWNER
AND TABLE_NAME = V_TABLE_NAME;


CURSOR C_REORG_3
IS
SELECT TABLE_OWNER, TABLE_NAME, TABLESPACE_NAME, SUBPARTITION_NAME
FROM DBA_TAB_SUBPARTITIONS
WHERE TABLE_OWNER = V_OWNER
AND TABLE_NAME = V_TABLE_NAME;

CURSOR C_CHECK_TB_SIZE
IS
SELECT SUM(BYTES/1024/1024) AS MB FROM 
DBA_SEGMENTS 
WHERE OWNER = V_OWNER
AND SEGMENT_NAME = V_TABLE_NAME;


CURSOR C_REORG_IND1
IS
SELECT OWNER, INDEX_NAME, TABLE_OWNER, TABLE_NAME, TABLESPACE_NAME, PARTITIONED
FROM DBA_INDEXES 
WHERE TABLE_OWNER = V_OWNER
AND TABLE_NAME = V_TABLE_NAME;

CURSOR C_REORG_IND2
IS
SELECT P.INDEX_OWNER, P.INDEX_NAME, I.TABLE_OWNER, I.TABLE_NAME, P.TABLESPACE_NAME, P.PARTITION_NAME
FROM DBA_INDEXES I, DBA_IND_PARTITIONS P
WHERE I.TABLE_OWNER = V_OWNER
AND I.TABLE_NAME = V_TABLE_NAME
AND I.OWNER = P.INDEX_OWNER
AND I.INDEX_NAME = P.INDEX_NAME;

CURSOR C_REORG_IND3
IS
SELECT SUB.INDEX_OWNER, SUB.INDEX_NAME, I.TABLE_OWNER, I.TABLE_NAME, SUB.TABLESPACE_NAME, SUB.SUBPARTITION_NAME
FROM DBA_INDEXES I, DBA_IND_SUBPARTITIONS SUB
WHERE I.TABLE_OWNER = V_OWNER
AND I.TABLE_NAME = V_TABLE_NAME
AND I.OWNER = SUB.INDEX_OWNER
AND I.INDEX_NAME = SUB.INDEX_NAME;


BEGIN

FOR I IN C_CHECK_TB_SIZE LOOP

	V_TB_SIZE := I.MB;

	DBMS_OUTPUT.PUT_LINE('BEFORE REORG TABLE SIZE: ' || V_TB_SIZE);

END LOOP;


FOR REC1 IN C_REORG_1 LOOP
	
	IF REC1.PARTITIONED = 'YES' THEN
	
		FOR REC3 IN C_REORG_3 LOOP
		
			IF REC3.SUBPARTITION_NAME IS NOT NULL THEN
			
				DBMS_OUTPUT.PUT_LINE('PERFORMED REORG ON SUBPARTITION: ' || REC3.SUBPARTITION_NAME);
			
				EXECUTE IMMEDIATE 'ALTER TABLE ' || V_OWNER || '.' || V_TABLE_NAME || ' MOVE SUBPARTITION ' || REC3.SUBPARTITION_NAME || ' TABLESPACE ' || REC3.TABLESPACE_NAME;
				
			END IF;

		END LOOP;
			
			
			FOR REC2 IN C_REORG_2 LOOP
			
				IF REC2.PARTITION_NAME IS NOT NULL THEN
			
					DBMS_OUTPUT.PUT_LINE('PERFORMED REORG ON PARTITION: ' || REC2.PARTITION_NAME);
					EXECUTE IMMEDIATE 'ALTER TABLE ' || V_OWNER || '.' || V_TABLE_NAME || ' MOVE PARTITION '  || REC2.PARTITION_NAME || ' TABLESPACE ' || REC2.TABLESPACE_NAME;
				
				ELSE 
				
					DBMS_OUTPUT.PUT_LINE('PERFORMED REORG ON TABLE: ' || V_TABLE_NAME);
						EXECUTE IMMEDIATE 'ALTER TABLE ' || V_OWNER || '.' || V_TABLE_NAME || ' MOVE TABLESPACE '  || REC1.TABLESPACE_NAME;
				
				END IF;
			END LOOP;
			
				FOR REC4 IN C_REORG_IND1 LOOP
					
					IF REC4.PARTITIONED = 'YES' THEN
					
						FOR REC5 IN C_REORG_IND3 LOOP
				
							IF REC5.SUBPARTITION_NAME IS NOT NULL THEN
				
								DBMS_OUTPUT.PUT_LINE('PERFORMED REORG ON INDEX SUBPARTITION: ' || REC5.SUBPARTITION_NAME);
								EXECUTE IMMEDIATE 'ALTER INDEX ' || REC5.INDEX_OWNER || '.' || REC5.INDEX_NAME || ' REBUILD SUBPARTITION ' || REC5.SUBPARTITION_NAME || ' TABLESPACE ' || REC5.TABLESPACE_NAME;
					
							END IF;
						END LOOP;
				
							FOR REC6 IN C_REORG_IND2 LOOP
					
								IF REC6.PARTITION_NAME IS NOT NULL THEN
						
									DBMS_OUTPUT.PUT_LINE('PERFORMED REORG ON INDEX PARTITION: ' || REC6.PARTITION_NAME);
									EXECUTE IMMEDIATE 'ALTER INDEX ' || REC6.INDEX_OWNER || '.' || REC6.INDEX_NAME || ' REBUILD PARTITION ' || REC6.PARTITION_NAME || ' TABLESPACE ' || REC6.TABLESPACE_NAME;
							
								ELSE 
						
									DBMS_OUTPUT.PUT_LINE('PERFORMED REORG ON INDEX: ' || REC4.INDEX_NAME);
									EXECUTE IMMEDIATE 'ALTER INDEX ' || REC4.OWNER || '.' || REC4.INDEX_NAME || ' REBUILD INDEX ONLINE';
								END IF;
							END LOOP;
					END IF;
				END LOOP;
        ELSE
        
		    DBMS_OUTPUT.PUT_LINE('PERFORMED REORG TABLE: ' || REC1.TABLE_NAME);
		    EXECUTE IMMEDIATE 'ALTER TABLE ' || V_OWNER || '.' || V_TABLE_NAME || ' MOVE TABLESPACE ' || REC1.TABLESPACE_NAME;
	END IF;
END LOOP;

FOR I IN C_CHECK_TB_SIZE LOOP

	V_TB_SIZE := I.MB;

	DBMS_OUTPUT.PUT_LINE('AFTER REORG TABLE SIZE: ' || V_TB_SIZE);

END LOOP;
END;
/


##### DNS LINUX AO INVÉS DO HOSTS
DNSMASQ.




### CHECAR COMANDOS DD CÓPIA REMOTA
dd if=/dev/sda1 ibs=4096 conv=notrunc,noerror | (ssh 132.183.12.128 dd of=/roarchive/test/roarchivetest.img obs=4096)

dd if=/dev/sda | gzip -1 - | ssh user@local dd of=image.gz

ssh user@remote "dd if=/dev/sda | gzip -1 -" | dd of=image.gz

------------------------------------------------------------------------------------------------------------

---###ODA (Oracle Database Appliance)

--- Default password SYS/SYSTEM initial deploy (welcome1)

--- List oakcli show -h

--- List ODA VERSION
/opt/oracle/oak/bin/oakcli show version

--- List/Show Databases ODA
/opt/oracle/oak/bin/oakcli show databases

--- List Database Homes ODA
/opt/oracle/oak/bin/oakcli show dbhome

--- List disks
/opt/oracle/oak/bin/oakcli show disk
/opt/oracle/oak/bin/oakcli show storage

--- List disks details
/opt/oracle/oak/bin/oakcli show disk e0_pd_23

--- List diskgroups
/opt/oracle/oak/bin/oakcli show diskgroup

--- List diskgroup details disks
/opt/oracle/oak/bin/oakcli show diskgroup DATA

--- List ASM ODA DISKS (Grid user)
asmcmd lsdsk

--- List repositories ODA
/opt/oracle/oak/bin/oakcli show repo

--- List VLAN ODA
/opt/oracle/oak/bin/oakcli show vlan

--- Validate patch version
/opt/oracle/oak/bin/oakcli validate -c ospatch -ver 12.1.2.2.0


--- Bare Metal

--- Validate Storage Topology
/opt/oracle/oak/bin/oakcli validate -c storagetopology

--- Configure Network 
/opt/oracle/oak/bin/oakcli configure firstnet

--- Unpack End-User Bundle
/opt/oracle/oak/bin/oakcli unpack -package /tmp/p12978712_xxxxx_Linux-x86-64.zip

--- Deploy Bundle Patch: (Start X Server)
/opt/oracle/oak/bin/oakcli deploy

--- Virtual Machine ODA

--- Deploy ODA BASE (When prompted for Location Enter Full Path Name for ODA_BASE: E.g.: /OVS/templateBuild-2014-04-19-02-33.tar.gz)
/opt/oracle/oak/bin/oakcli deploy oda_base


---- List command to validate
/opt/oracle/oak/bin/oakcli validate -l

--- Validate everything ODA
/opt/oracle/oak/bin/oakcli validate -a

--- Validate System and Network Components
/opt/oracle/oak/bin/oakcli validate -c SystemComponents,NetworkComponents

--- List oakcli show power supply infos
/opt/oracle/oak/bin/oakcli show power




select * from users where  REGEXP_LIKE (first_name, '^[^0-9a-z]+$', 'i');


find ./ -name "*.trc" -exec echo {} \; | awk '{print echo "echo > " $1}' > zeratrace.sh ; chmod +x zeratrace.sh ; nohup ./zeratrace.sh &

find ./ -name "*.trc" -mtime +5 -exec echo {} \; | awk '{print echo "echo > " $1}' > zeratrace.sh ; chmod +x zeratrace.sh ; nohup ./zeratrace.sh &


find ./ -name "*.trm" -exec echo {} \; | awk '{print echo "echo > " $1}' > zeratrace.sh ; chmod +x zeratrace.sh ; nohup ./zeratrace.sh &

find ./ -name "*.trm" -mtime +5 -exec echo {} \; | awk '{print echo "echo > " $1}' > zeratrace.sh ; chmod +x zeratrace.sh ; nohup ./zeratrace.sh &

--- Gerar SQL No Excel: 
="update lsantos.tb_migexa_instance set exavm_target = '" &E53&"' where instance_name = '"&C53&"';"

# xenstore-ls -f | grep <UUID>.img 
Please replace "<UUID>" with the UUID of the disk. 

It will provide an output similar to below: 
/local/domain/0/backend/vbd/10/51712/params = "/OVS/Repositories/0004fb0000030000bbc006a036a18a87/VirtualDisks/0004fb000012000063c8261d09e4b9b9.img" 

In this example, the virtual block device (vbd) ID is 51712. The value of 10 is the VM ID that can be found through "xm list" command. Please compare the VM ID with the output of "xm list" command to ensure it maps to the VM. 

Use the values taken from the output to force removal of the disks: 

# xm block-detach 10 51712 -f 

This will remove the virtual block device. 

Or 

++ You need to stop the VM 
++ Edit the vm.cfg file manually(Please be careful while editing) 
++ Start the VM 
