-- -----------------------------------------------------------------------------------
-- FILE NAME    : USER_DDL.SQL
-- AUTHOR       : SADOK NASRI
-- DESCRIPTION  : DISPLAYS THE DDL FOR A SPECIFIC USER.
-- CALL SYNTAX  : @USER_DDL (USERNAME)
-- -----------------------------------------------------------------------------------

SET LONG 20000 LONGCHUNKSIZE 20000 PAGESIZE 0 LINESIZE 1000 FEEDBACK OFF VERIFY OFF TRIMSPOOL ON ECHO OFF
COLUMN DDL FORMAT A1000

BEGIN
   DBMS_METADATA.SET_TRANSFORM_PARAM (DBMS_METADATA.SESSION_TRANSFORM, 'SQLTERMINATOR', TRUE);
   DBMS_METADATA.SET_TRANSFORM_PARAM (DBMS_METADATA.SESSION_TRANSFORM, 'PRETTY', TRUE);
END;
/

VARIABLE V_USERNAME VARCHAR2(30);
COLUMN TREE NOPRINT

EXEC:V_USERNAME := UPPER('&1');

SELECT 1 TREE, DBMS_METADATA.GET_DDL('USER', U.USERNAME) AS DDL
FROM   DBA_USERS U
WHERE  U.USERNAME = :V_USERNAME
UNION ALL
SELECT 2 TREE, DBMS_METADATA.GET_GRANTED_DDL('TABLESPACE_QUOTA', TQ.USERNAME) AS DDL
FROM   DBA_TS_QUOTAS TQ
WHERE  TQ.USERNAME = :V_USERNAME
AND    ROWNUM = 1
UNION ALL
SELECT 3 TREE, DBMS_METADATA.GET_GRANTED_DDL('ROLE_GRANT', RP.GRANTEE) AS DDL
FROM   DBA_ROLE_PRIVS RP
WHERE  RP.GRANTEE = :V_USERNAME
AND    ROWNUM = 1
UNION ALL
SELECT 4 TREE, DBMS_METADATA.GET_GRANTED_DDL('SYSTEM_GRANT', SP.GRANTEE) AS DDL
FROM   DBA_SYS_PRIVS SP
WHERE  SP.GRANTEE = :V_USERNAME
AND    ROWNUM = 1
UNION ALL
SELECT 5 TREE, DBMS_METADATA.GET_GRANTED_DDL('OBJECT_GRANT', TP.GRANTEE) AS DDL
FROM   DBA_TAB_PRIVS TP
WHERE  TP.GRANTEE = :V_USERNAME
AND    ROWNUM = 1
UNION ALL
SELECT 6 TREE, DBMS_METADATA.GET_GRANTED_DDL('DEFAULT_ROLE', RP.GRANTEE) AS DDL
FROM   DBA_ROLE_PRIVS RP
WHERE  RP.GRANTEE = :V_USERNAME
AND    RP.DEFAULT_ROLE = 'YES'
AND    ROWNUM = 1
UNION ALL
SELECT 7 TREE, TO_CLOB('/* START PROFILE CREATION SCRIPT IN CASE THEY ARE MISSING') AS DDL
FROM   DBA_USERS U
WHERE  U.USERNAME = :V_USERNAME
AND    U.PROFILE <> 'DEFAULT'
AND    ROWNUM = 1
UNION ALL
SELECT 8 TREE, DBMS_METADATA.GET_DDL('PROFILE', U.PROFILE) AS DDL
FROM   DBA_USERS U
WHERE  U.USERNAME = :V_USERNAME
AND    U.PROFILE <> 'DEFAULT'
UNION ALL
SELECT 9 TREE, TO_CLOB('END PROFILE CREATION SCRIPT */') AS DDL
FROM   DBA_USERS U
WHERE  U.USERNAME = :V_USERNAME
AND    U.PROFILE <> 'DEFAULT'
AND    ROWNUM = 1
ORDER BY TREE
/

SET LINESIZE 100 PAGESIZE 14 FEEDBACK ON TRIMSPOOL ON VERIFY ON

